@@ -30,24 +30,24 @@
 // The 3rd usage (mis_demo 1 ...) creates a finite-element matrix on an
 // nx-by-ny grid.  Method is 0 to 3; refer to wathen.c for details.
 
-#include "demos.h"
-
 // macro used by OK(...) to free workspace if an error occurs
-#define FREE_ALL                \
-    GrB_Matrix_free (&A) ;             \
-    GrB_Matrix_free (&C) ;             \
-    GrB_Vector_free (&iset1) ;         \
-    GrB_Vector_free (&iset2) ;         \
-    GrB_Vector_free (&e) ;             \
-    GrB_Descriptor_free (&dt) ;            \
-    GrB_Monoid_free (&Lor) ;           \
-    GrB_Semiring_free (&Boolean) ;       \
-    if (I2 != NULL) free (I2) ; \
-    if (J2 != NULL) free (J2) ; \
-    if (X2 != NULL) free (X2) ; \
-    if (I != NULL) free (I) ;   \
+#define FREE_ALL                        \
+    GrB_Matrix_free (&A) ;              \
+    GrB_Matrix_free (&C) ;              \
+    GrB_Vector_free (&iset1) ;          \
+    GrB_Vector_free (&iset2) ;          \
+    GrB_Vector_free (&e) ;              \
+    GrB_Descriptor_free (&dt) ;         \
+    GrB_Monoid_free (&Lor) ;            \
+    GrB_Semiring_free (&Boolean) ;      \
+    if (I2 != NULL) free (I2) ;         \
+    if (J2 != NULL) free (J2) ;         \
+    if (X2 != NULL) free (X2) ;         \
+    if (I != NULL) free (I) ;           \
     if (X != NULL) free (X) ;
 
+#include "graphblas_demos.h"
+
 int64_t isize1, isize2 ;
 GrB_Index n ;
 GrB_Matrix A = NULL, C = NULL ;
@@ -77,14 +77,14 @@ GrB_Info mis_check_results
     //--------------------------------------------------------------------------
 
     int64_t isize ;
-    OK (GrB_Vector_reduce_INT64 (&isize, NULL, GxB_PLUS_INT64_MONOID,
+    OK (GrB_Vector_reduce_INT64 (&isize, NULL, GrB_PLUS_MONOID_INT64,
         iset, NULL)) ;
     (*p_isize) = isize ;
 
     GrB_Index nvals ;
     OK (GrB_Vector_nvals (&nvals, iset)) ;
-    I = malloc (nvals * sizeof (GrB_Index)) ;
-    X = malloc (nvals * sizeof (float)) ;
+    I = (GrB_Index *) malloc (nvals * sizeof (GrB_Index)) ;
+    X = (float *) malloc (nvals * sizeof (float)) ;
 
     if (I == NULL || X == NULL)
     {
@@ -119,9 +119,9 @@ GrB_Info mis_check_results
     OK (GrB_Matrix_extract (C, NULL, NULL, A, I, isize, I, isize, NULL)) ;
     OK (GrB_Matrix_nvals (&nvals, C)) ;
 
-    I2 = malloc (nvals * sizeof (GrB_Index)) ;
-    J2 = malloc (nvals * sizeof (GrB_Index)) ;
-    X2 = malloc (nvals * sizeof (bool)) ;
+    I2 = (GrB_Index *) malloc (nvals * sizeof (GrB_Index)) ;
+    J2 = (GrB_Index *) malloc (nvals * sizeof (GrB_Index)) ;
+    X2 = (bool *) malloc (nvals * sizeof (bool)) ;
     if (I2 == NULL || J2 == NULL || X2 == NULL)
     {
         printf ("out of memory\n") ;
@@ -178,7 +178,7 @@ int main (int argc, char **argv)
     double tic [2], t1, t2 ;
     OK (GrB_init (GrB_NONBLOCKING)) ;
     int nthreads ;
-    OK (GxB_get (GxB_NTHREADS, &nthreads)) ;
+    OK (GxB_Global_Option_get (GxB_GLOBAL_NTHREADS, &nthreads)) ;
     fprintf (stderr, "\nmis_demo: nthreads: %d\n", nthreads) ;
 
     //--------------------------------------------------------------------------
