@@ -28,7 +28,32 @@
 // simple illustration.  Use the LAGraph_bfs_pushpull for benchmarking and
 // production use.
 
-#include "demos.h"
+#include "GraphBLAS.h"
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
+
+//------------------------------------------------------------------------------
+// bfs_level: for unary operator
+//------------------------------------------------------------------------------
+
+// level = depth in BFS traversal, roots=1, unvisited=0.
+
+// Note the operator accesses a global variable outside the control of
+// GraphBLAS.  This is safe, but care must be taken not to change the global
+// variable "level" while pending operations have yet to be completed.
+
+int32_t bfs_level_global = 0 ;
+
+void bfs_level (void *result, const void *element)
+{
+    // Note this function does not depend on its input.  It returns the value
+    // of the global variable level for all inputs.  It is applied to the
+    // vector q via GrB_apply, which only applies the unary operator to entries
+    // in the pattern.  Entries not in the pattern remain implicit (zero in
+    // this case), and then are not added by the GrB_PLUS_INT32 accum function.
+    (* ((int32_t *) result)) = bfs_level_global ;
+}
 
 //------------------------------------------------------------------------------
 // bfs6: breadth first search using a Boolean semiring
@@ -40,7 +65,8 @@
 // v should be empty on input.)  The graph A need not be Boolean on input;
 // if it isn't Boolean, the semiring will properly typecast it to Boolean.
 
-GrB_Info bfs6               // BFS of a graph (using unary operator)
+GB_PUBLIC
+GrB_Info bfs6               // BFS of a graph (using apply)
 (
     GrB_Vector *v_output,   // v [i] is the BFS level of node i in the graph
     const GrB_Matrix A,     // input graph, treated as if boolean in semiring
@@ -55,10 +81,9 @@ GrB_Info bfs6               // BFS of a graph (using unary operator)
     GrB_Index n ;                          // # of nodes in the graph
     GrB_Vector q = NULL ;                  // nodes visited at each level
     GrB_Vector v = NULL ;                  // result vector
-    GrB_Monoid Lor = NULL ;                // Logical-or monoid
-    GrB_Semiring Boolean = NULL ;          // Boolean semiring
     GrB_Descriptor desc = NULL ;           // Descriptor for vxm
-    GrB_UnaryOp apply_level = NULL ;       // unary op: z = f(x) = level
+    GrB_UnaryOp apply_level = NULL ;       // unary op:
+                                           // z = f(x) = bfs_level_global
 
     GrB_Matrix_nrows (&n, A) ;             // n = # of rows of A
     GrB_Vector_new (&v, GrB_INT32, n) ;    // Vector<int32_t> v(n) = 0
@@ -68,15 +93,6 @@ GrB_Info bfs6               // BFS of a graph (using unary operator)
     GrB_Vector_new (&q, GrB_BOOL, n) ;     // Vector<bool> q(n) = false
     GrB_Vector_setElement_BOOL (q, true, s) ;   // q[s] = true, false elsewhere
 
-    // Note the typecast to bool.  Otherwise an error is reported, since the
-    // _Generic function selects the wrong function (int32, not boolean).  This
-    // is because of default integer promotion of function arguments in C.
-    GrB_Monoid_new_BOOL (&Lor, GrB_LOR, (bool) false) ;
-
-    // The semiring uses "AND" as the multiply operator, and "OR" as the
-    // addititive monoid.
-    GrB_Semiring_new (&Boolean, Lor, GrB_LAND) ;
-
     GrB_Descriptor_new (&desc) ;
     GrB_Descriptor_set (desc, GrB_MASK, GrB_COMP) ;     // invert the mask
     GrB_Descriptor_set (desc, GrB_OUTP, GrB_REPLACE) ;  // clear q first
@@ -89,21 +105,22 @@ GrB_Info bfs6               // BFS of a graph (using unary operator)
     //--------------------------------------------------------------------------
 
     bool successor = true ; // true when some successor found
-    for (level = 1 ; successor && level <= n ; level++)
+    for (bfs_level_global = 1 ; successor && bfs_level_global <= n ; 
+         bfs_level_global++)
     {
 
-        // v[q] = level, using apply.  This function applies the unary operator
-        // to the entries in q, which are the unvisited successors, and then
-        // writes their levels to v, thus updating the levels of those nodes in
-        // v.  The patterns of v and q are disjoint.
+        // v[q] = bfs_level_global, using apply.  This function applies the
+        // unary operator to the entries in q, which are the unvisited
+        // successors, and then writes their levels to v, thus updating the
+        // levels of those nodes in v.  The patterns of v and q are disjoint.
         GrB_Vector_apply (v, NULL, GrB_PLUS_INT32, apply_level, q, NULL) ;
 
         // q<!v> = q ||.&& A ; finds all the unvisited
         // successors from current q, using !v as the mask
-        GrB_vxm (q, v, NULL, Boolean, q, A, desc) ;
+        GrB_vxm (q, v, NULL, GrB_LOR_LAND_SEMIRING_BOOL, q, A, desc) ;
 
         // successor = ||(q)
-        GrB_Vector_reduce_BOOL (&successor, NULL, Lor, q, NULL) ;
+        GrB_Vector_reduce_BOOL (&successor, NULL, GrB_LOR_MONOID_BOOL, q, NULL) ;
     }
 
     // make v sparse
@@ -113,8 +130,6 @@ GrB_Info bfs6               // BFS of a graph (using unary operator)
     *v_output = v ;         // return result
 
     GrB_Vector_free (&q) ;
-    GrB_Monoid_free (&Lor) ;
-    GrB_Semiring_free (&Boolean) ;
     GrB_Descriptor_free (&desc) ;
     GrB_UnaryOp_free (&apply_level) ;
 
