@@ -19,11 +19,6 @@
 // instead of GrB_mxv.  It now more closely matches the BFS example in the
 // GraphBLAS C API Specification.
 
-// This version uses a predefined semiring (GxB_LOR_LAND_BOOL) and a predefined
-// monoid (GxB_LOR_BOOL_MONOID), in GraphBLAS.h.  It also checks the status of
-// each call to GraphBLAS functions.  These two changes are unrelated.  Both
-// change are made here to illustrate two different things.
-
 // "OK(x)" macro calls a GraphBLAS method, and if it fails, prints the error,
 // frees workspace, and returns to the caller.  It uses the FREE_ALL macro
 // to free the workspace
@@ -37,13 +32,39 @@
 // simple illustration.  Use the LAGraph_bfs_pushpull for benchmarking and
 // production use.
 
-#define FREE_ALL                \
-    GrB_Vector_free (&v) ;             \
-    GrB_Vector_free (&q) ;             \
-    GrB_Descriptor_free (&desc) ;          \
+#include "GraphBLAS.h"
+
+#define FREE_ALL                        \
+    GrB_Vector_free (&v) ;              \
+    GrB_Vector_free (&q) ;              \
+    GrB_Descriptor_free (&desc) ;       \
     GrB_UnaryOp_free (&apply_level) ;
 
-#include "demos.h"
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
+
+//------------------------------------------------------------------------------
+// bfs_level2: for unary operator
+//------------------------------------------------------------------------------
+
+// level = depth in BFS traversal, roots=1, unvisited=0.
+
+// Note the operator accesses a global variable outside the control of
+// GraphBLAS.  This is safe, but care must be taken not to change the global
+// variable "level" while pending operations have yet to be completed.
+
+int32_t bfs_level2_global = 0 ;
+
+void bfs_level2 (void *result, const void *element)
+{
+    // Note this function does not depend on its input.  It returns the value
+    // of the global variable level for all inputs.  It is applied to the
+    // vector q via GrB_apply, which only applies the unary operator to entries
+    // in the pattern.  Entries not in the pattern remain implicit (zero in
+    // this case), and then are not added by the GrB_PLUS_INT32 accum function.
+    (* ((int32_t *) result)) = bfs_level2_global ;
+}
 
 //------------------------------------------------------------------------------
 // bfs6: breadth first search using a Boolean semiring
@@ -55,7 +76,8 @@
 // v should be empty on input.)  The graph A need not be Boolean on input;
 // if it isn't Boolean, the semiring will properly typecast it to Boolean.
 
-GrB_Info bfs6_check         // BFS of a graph (using unary operator)
+GB_PUBLIC
+GrB_Info bfs6_check         // BFS of a graph (using apply)
 (
     GrB_Vector *v_output,   // v [i] is the BFS level of node i in the graph
     const GrB_Matrix A,     // input graph, treated as if boolean in semiring
@@ -72,7 +94,8 @@ GrB_Info bfs6_check         // BFS of a graph (using unary operator)
     GrB_Vector q = NULL ;                       // nodes visited at each level
     GrB_Vector v = NULL ;                       // result vector
     GrB_Descriptor desc = NULL ;                // Descriptor for vxm
-    GrB_UnaryOp apply_level = NULL ;            // unary op: z = f(x) = level
+    GrB_UnaryOp apply_level = NULL ;            // unary op:
+                                                // z = f(x) = bfs_level2_global
 
     OK (GrB_Matrix_nrows (&n, A)) ;             // n = # of rows of A
     OK (GrB_Vector_new (&v, GrB_INT32, n)) ;    // Vector<int32_t> v(n) = 0
@@ -88,27 +111,29 @@ GrB_Info bfs6_check         // BFS of a graph (using unary operator)
     OK (GxB_Desc_set (desc, GrB_OUTP, GrB_REPLACE)) ;
 
     // create a unary operator
-    OK (GrB_UnaryOp_new (&apply_level, bfs_level, GrB_INT32, GrB_BOOL)) ;
+    OK (GrB_UnaryOp_new (&apply_level, bfs_level2, GrB_INT32, GrB_BOOL)) ;
 
     //--------------------------------------------------------------------------
     // BFS traversal and label the nodes
     //--------------------------------------------------------------------------
 
     bool successor = true ; // true when some successor found
-    for (level = 1 ; successor && level <= n ; level++)
+    for (bfs_level2_global = 1 ; successor && bfs_level2_global <= n ;
+         bfs_level2_global++)
     {
-        // v[q] = level, using apply.  This function applies the unary operator
-        // to the entries in q, which are the unvisited successors, and then
-        // writes their levels to v, thus updating the levels of those nodes in
-        // v.  The patterns of v and q are disjoint.
+        // v[q] = bfs_level2_global, using apply.  This function applies the
+        // unary operator to the entries in q, which are the unvisited
+        // successors, and then writes their levels to v, thus updating the
+        // levels of those nodes in v.  The patterns of v and q are disjoint.
+
         OK (GrB_Vector_apply (v, NULL, GrB_PLUS_INT32, apply_level, q, NULL)) ;
 
         // q'<!v> = q ||.&& A ; finds all the unvisited
         // successors from current q, using !v as the mask
-        OK (GrB_vxm (q, v, NULL, GxB_LOR_LAND_BOOL, q, A, desc)) ;
+        OK (GrB_vxm (q, v, NULL, GrB_LOR_LAND_SEMIRING_BOOL, q, A, desc)) ;
 
         // successor = ||(q)
-        GrB_Vector_reduce_BOOL (&successor, NULL, GxB_LOR_BOOL_MONOID,
+        GrB_Vector_reduce_BOOL (&successor, NULL, GrB_LOR_MONOID_BOOL,
             q, NULL) ;
     }
 
