@@ -24,31 +24,33 @@
 // Acknowledgements:  this method was written with input from Richard Veras,
 // Franz Franchetti, and Scott McMillan, Carnegie Mellon University.
 
+#include "GraphBLAS.h"
+
 //------------------------------------------------------------------------------
 // helper macros
 //------------------------------------------------------------------------------
 
 // free all workspace
-#define FREEWORK                    \
-{                                   \
-    GrB_Vector_free (&rdouble) ;           \
-    GrB_Vector_free (&r) ;                 \
-    GrB_Vector_free (&rnew) ;              \
-    GrB_Vector_free (&dout) ;              \
-    GrB_Vector_free (&rdiff) ;             \
-    GrB_Descriptor_free (&desc) ;              \
-    if (I != NULL) free (I) ;       \
-    if (X != NULL) free (X) ;       \
-    GrB_BinaryOp_free (&PageRank_accum) ;    \
-    GrB_BinaryOp_free (&PageRank_add) ;      \
-    GrB_Monoid_free (&PageRank_monoid) ;   \
-    GrB_BinaryOp_free (&PageRank_multiply) ; \
-    GrB_Semiring_free (&PageRank_semiring) ; \
-    GrB_BinaryOp_free (&PageRank_diff) ;     \
-    GrB_Type_free (&PageRank_type) ;     \
-    GrB_UnaryOp_free (&PageRank_div) ;      \
-    GrB_UnaryOp_free (&PageRank_get) ;      \
-    GrB_UnaryOp_free (&PageRank_init) ;     \
+#define FREEWORK                                \
+{                                               \
+    GrB_Vector_free (&rdouble) ;                \
+    GrB_Vector_free (&r) ;                      \
+    GrB_Vector_free (&rnew) ;                   \
+    GrB_Vector_free (&dout) ;                   \
+    GrB_Vector_free (&rdiff) ;                  \
+    GrB_Descriptor_free (&desc) ;               \
+    if (I != NULL) free (I) ;                   \
+    if (X != NULL) free (X) ;                   \
+    GrB_BinaryOp_free (&PageRank_accum) ;       \
+    GrB_BinaryOp_free (&PageRank_add) ;         \
+    GrB_Monoid_free (&PageRank_monoid) ;        \
+    GrB_BinaryOp_free (&PageRank_multiply) ;    \
+    GrB_Semiring_free (&PageRank_semiring) ;    \
+    GrB_BinaryOp_free (&PageRank_diff) ;        \
+    GrB_Type_free (&PageRank_type) ;            \
+    GrB_UnaryOp_free (&PageRank_div) ;          \
+    GrB_UnaryOp_free (&PageRank_get) ;          \
+    GrB_UnaryOp_free (&PageRank_init) ;         \
 }
 
 // error handler: free output P and all workspace (used by CHECK and OK macros)
@@ -58,7 +60,9 @@
     FREEWORK ;                  \
 }
 
-#include "demos.h"
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
 
 //------------------------------------------------------------------------------
 // scalar types and operators
@@ -225,6 +229,7 @@ int pagerank_compar (const void *x, const void *y)
 // dpagerank2: compute the PageRank of all nodes in a graph
 //------------------------------------------------------------------------------
 
+GB_PUBLIC
 GrB_Info dpagerank2         // GrB_SUCCESS or error condition
 (
     PageRank **Phandle,     // output: pointer to array of PageRank structs
@@ -257,20 +262,23 @@ GrB_Info dpagerank2         // GrB_SUCCESS or error condition
     // create the new Page type
     OK (GrB_Type_new (&PageRank_type, sizeof (pagerank_type))) ;
 
+    #define U (GxB_unary_function)
+    #define B (GxB_binary_function)
+
     // create the unary operator to initialize the PageRank_type of each node
-    OK (GrB_UnaryOp_new (&PageRank_init, init_page, PageRank_type, GrB_FP64)) ;
+    OK (GrB_UnaryOp_new (&PageRank_init, U init_page, PageRank_type, GrB_FP64));
 
     // create PageRank_accum
-    OK (GrB_BinaryOp_new (&PageRank_accum, pagerank_accum,
+    OK (GrB_BinaryOp_new (&PageRank_accum, B pagerank_accum,
         PageRank_type, PageRank_type, PageRank_type)) ;
 
     // create PageRank_add operator and monoid
-    OK (GrB_BinaryOp_new (&PageRank_add, pagerank_add,
+    OK (GrB_BinaryOp_new (&PageRank_add, B pagerank_add,
         PageRank_type, PageRank_type, PageRank_type)) ;
     OK (GrB_Monoid_new_UDT (&PageRank_monoid, PageRank_add, &pagerank_zero)) ;
 
     // create PageRank_multiply operator
-    OK (GrB_BinaryOp_new (&PageRank_multiply, pagerank_multiply,
+    OK (GrB_BinaryOp_new (&PageRank_multiply, B pagerank_multiply,
         PageRank_type, PageRank_type, GrB_BOOL)) ;
 
     // create PageRank_semiring
@@ -278,14 +286,14 @@ GrB_Info dpagerank2         // GrB_SUCCESS or error condition
         PageRank_multiply)) ;
 
     // create unary operator that typecasts the PageRank_type to double
-    OK (GrB_UnaryOp_new (&PageRank_get, pagerank_get_rank, GrB_FP64,
+    OK (GrB_UnaryOp_new (&PageRank_get, U pagerank_get_rank, GrB_FP64,
         PageRank_type)) ;
 
     // create unary operator that scales the rank by pagerank_rsum
-    OK (GrB_UnaryOp_new (&PageRank_div, pagerank_div, GrB_FP64, GrB_FP64)) ;
+    OK (GrB_UnaryOp_new (&PageRank_div, U pagerank_div, GrB_FP64, GrB_FP64)) ;
 
     // create PageRank_diff operator
-    OK (GrB_BinaryOp_new (&PageRank_diff, pagerank_diff,
+    OK (GrB_BinaryOp_new (&PageRank_diff, B pagerank_diff,
         PageRank_type, PageRank_type, PageRank_type)) ;
 
     //--------------------------------------------------------------------------
@@ -344,7 +352,7 @@ GrB_Info dpagerank2         // GrB_SUCCESS or error condition
             desc)) ;
 
         // compute pagerank_rdiff = sum ((r - rnew).^2)
-        OK (GrB_eWiseAdd_Vector_BinaryOp (rdiff, NULL, NULL, PageRank_diff,
+        OK (GrB_Vector_eWiseAdd_BinaryOp (rdiff, NULL, NULL, PageRank_diff,
             r, rnew, NULL)) ;
         pagerank_type rsum ;
         OK (GrB_Vector_reduce_UDT (&rsum, NULL, PageRank_monoid, rdiff, NULL)) ;
@@ -371,7 +379,7 @@ GrB_Info dpagerank2         // GrB_SUCCESS or error condition
     GrB_Vector_free (&r) ;
 
     // pagerank_rsum = sum (rdouble)
-    OK (GrB_Vector_reduce_FP64 (&pagerank_rsum, NULL, GxB_PLUS_FP64_MONOID,
+    OK (GrB_Vector_reduce_FP64 (&pagerank_rsum, NULL, GrB_PLUS_MONOID_FP64,
         rdouble, NULL)) ;
 
     // could also do this with GrB_vxm, with a 1-by-1 matrix
@@ -389,8 +397,8 @@ GrB_Info dpagerank2         // GrB_SUCCESS or error condition
     // [r,irank] = sort (r, 'descend') ;
 
     // [I,X] = find (r) ;
-    X = malloc (n * sizeof (double)) ;
-    I = malloc (n * sizeof (GrB_Index)) ;
+    X = (double *) malloc (n * sizeof (double)) ;
+    I = (GrB_Index *) malloc (n * sizeof (GrB_Index)) ;
     CHECK (I != NULL && X != NULL, GrB_OUT_OF_MEMORY) ;
     GrB_Index nvals = n ;
     OK (GrB_Vector_extractTuples_FP64 (I, X, &nvals, rdouble)) ;
@@ -399,7 +407,7 @@ GrB_Info dpagerank2         // GrB_SUCCESS or error condition
     GrB_Vector_free (&rdouble) ;
 
     // P = struct (X,I)
-    P = malloc (n * sizeof (PageRank)) ;
+    P = (PageRank *) malloc (n * sizeof (PageRank)) ;
     CHECK (P != NULL, GrB_OUT_OF_MEMORY) ;
     int64_t k ;
     for (k = 0 ; k < nvals ; k++)
