@@ -10,13 +10,18 @@
 // Creates a symmetric matrix, either from a file or by creating a random
 // matrix.  If reading from a file, the file is assumed to be 0-based.
 
-#define FREE_ALL        \
-    GrB_Matrix_free (&A) ;     \
-    GrB_Descriptor_free (&desc) ;  \
+#include "GraphBLAS.h"
+
+#define FREE_ALL                    \
+    GrB_Matrix_free (&A) ;          \
+    GrB_Descriptor_free (&desc) ;   \
     GrB_Matrix_free (&Mask) ;
 
-#include "demos.h"
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
 
+GB_PUBLIC
 GrB_Info get_matrix         // get a matrix from stdin, or create random one
 (
     GrB_Matrix *A_output,   // matrix to create
