@@ -7,7 +7,11 @@
 
 //------------------------------------------------------------------------------
 
-#include "demos.h"
+#include "GraphBLAS.h"
+
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
 
 #if defined __INTEL_COMPILER
 #pragma warning (disable: 556)
@@ -15,7 +19,7 @@
 
 #define FREE_ALL                    \
 {                                   \
-    GrB_Matrix_free (C_handle) ;           \
+    GrB_Matrix_free (C_handle) ;    \
     if (Ap != NULL) free (Ap) ;     \
     if (Ah != NULL) free (Ah) ;     \
     if (Ai != NULL) free (Ai) ;     \
@@ -24,7 +28,7 @@
 }
 
 // typecast the values to the exported type
-#define GETVAL \
+#define GETVAL                                                  \
 {                                                               \
     if      (type == GrB_BOOL  ) Ax_bool   = (bool     *) Ax ;  \
     else if (type == GrB_INT8  ) Ax_int8   = (int8_t   *) Ax ;  \
@@ -41,7 +45,7 @@
 }
 
 // print a value
-#define PRINTVAL(p) \
+#define PRINTVAL(p)                                                      \
 {                                                                        \
     if      (type == GrB_BOOL  ) printf ("%g", (double) Ax_bool   [p]) ; \
     else if (type == GrB_INT8  ) printf ("%g", (double) Ax_int8   [p]) ; \
@@ -58,6 +62,7 @@
 
 #include "../Source/GB.h"
 
+GB_PUBLIC
 GrB_Info import_test (GrB_Matrix *C_handle, int format, bool dump)
 {
     
@@ -72,11 +77,11 @@ GrB_Info import_test (GrB_Matrix *C_handle, int format, bool dump)
     int8_t   *Ax_int8   = NULL ;
     int16_t  *Ax_int16  = NULL ;
     int32_t  *Ax_int32  = NULL ;
-    int32_t  *Ax_int64  = NULL ;
+    int64_t  *Ax_int64  = NULL ;
     uint8_t  *Ax_uint8  = NULL ;
     uint16_t *Ax_uint16 = NULL ;
     uint32_t *Ax_uint32 = NULL ;
-    uint32_t *Ax_uint64 = NULL ;
+    uint64_t *Ax_uint64 = NULL ;
     float    *Ax_fp32   = NULL ;
     double   *Ax_fp64   = NULL ;
 
