@@ -19,7 +19,10 @@
 // NaN equality (like isequalwithequalnans in MATLAB), use isequal_type with a
 // user-defined operator f(x,y) that returns true if x and y are both NaN.
 
-#include "demos.h"
+#include "GraphBLAS.h"
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
 
 // call a GraphBLAS method and return if an error occurs
 #undef  OK
@@ -30,7 +33,6 @@
     {                                                       \
         /* error occured: free workspace and return */      \
         GrB_Matrix_free (&C) ;                              \
-        GrB_Monoid_free (&monoid) ;                         \
         return (info) ;                                     \
     }                                                       \
 }
@@ -39,6 +41,7 @@
 // isequal_type: check two matrices, works in any GraphBLAS
 //------------------------------------------------------------------------------
 
+GB_PUBLIC
 GrB_Info isequal_type       // return GrB_SUCCESS if successful
 (
     bool *result,           // true if A == B, false if A != B or error
@@ -49,7 +52,6 @@ GrB_Info isequal_type       // return GrB_SUCCESS if successful
 {
 
     GrB_Matrix C = NULL ;
-    GrB_Monoid monoid = NULL ;
     GrB_Index nrows1, ncols1, nrows2, ncols2, nvals, nvals1, nvals2 ;
 
     if (result == NULL)
@@ -87,7 +89,7 @@ GrB_Info isequal_type       // return GrB_SUCCESS if successful
 
     // C = A .* B, where the pattern of C is the intersection of A and B
     OK (GrB_Matrix_new (&C, GrB_BOOL, nrows1, ncols1)) ;
-    OK (GrB_eWiseMult_Matrix_BinaryOp (C, NULL, NULL, op, A, B, NULL)) ;
+    OK (GrB_Matrix_eWiseMult_BinaryOp (C, NULL, NULL, op, A, B, NULL)) ;
 
     // ensure C has the same number of entries as A and B
     OK (GrB_Matrix_nvals (&nvals, C)) ;
@@ -98,19 +100,11 @@ GrB_Info isequal_type       // return GrB_SUCCESS if successful
         return (GrB_SUCCESS) ;
     }
 
-    #ifdef GxB_SUITESPARSE_GRAPHBLAS
-    // SuiteSparse has a predefined boolean AND monoid
-    monoid = GxB_LAND_BOOL_MONOID ;
-    #else
-    OK (GrB_Monoid_new_BOOL (&monoid, GrB_LAND, true)) ;
-    #endif
-
     // result = and (C)
-    OK (GrB_Matrix_reduce_BOOL (result, NULL, monoid, C, NULL)) ;
+    OK (GrB_Matrix_reduce_BOOL (result, NULL, GrB_LAND_MONOID_BOOL, C, NULL)) ;
 
     // free workspace and return result
     GrB_Matrix_free (&C) ;
-    GrB_Monoid_free (&monoid) ;
     return (GrB_SUCCESS) ;
 }
 
@@ -131,7 +125,6 @@ GrB_Info isequal            // return GrB_SUCCESS if successful
 )
 {
     GrB_Matrix C = NULL ;
-    GrB_Monoid monoid = NULL ;
     GrB_Type atype, btype ;
     GrB_BinaryOp op ;
 
@@ -163,6 +156,8 @@ GrB_Info isequal            // return GrB_SUCCESS if successful
     else if (atype == GrB_UINT64) op = GrB_EQ_UINT64 ;
     else if (atype == GrB_FP32  ) op = GrB_EQ_FP32   ;
     else if (atype == GrB_FP64  ) op = GrB_EQ_FP64   ;
+    else if (atype == GxB_FC32  ) op = GxB_EQ_FC32   ;
+    else if (atype == GxB_FC64  ) op = GxB_EQ_FC64   ;
     else                          op = userop ; // A and B are user-defined
 
     // check the size, pattern, and values of A and B
