@@ -45,7 +45,7 @@
 // relevant references.
 
 // All input matrices should have binary values (0 and 1).  Any type will work,
-// but uint32 is recommended for fastest results since that is the type used
+// but int32 is recommended for fastest results since that is the type used
 // here for the semiring.  GraphBLAS will do typecasting internally, but that
 // takes extra time. 
 
@@ -55,19 +55,23 @@
 // C<M>=A'*B uses the dot product method by default, whereas C<M>=A*B' uses the
 // dot product method if the matrices are stored by row.
 
+#include "GraphBLAS.h"
+
 #define FREE_ALL                \
-    GrB_UnaryOp_free (&Two) ;           \
-    GrB_Descriptor_free (&d) ;             \
-    GrB_Matrix_free (&S) ;             \
+    GrB_UnaryOp_free (&Two) ;   \
+    GrB_Descriptor_free (&d) ;  \
+    GrB_Matrix_free (&S) ;      \
     GrB_Matrix_free (&C) ;
 
-#include "demos.h"
+#undef GB_PUBLIC
+#define GB_LIBRARY
+#include "graphblas_demos.h"
 
 //------------------------------------------------------------------------------
 // two:  unary function for GrB_apply
 //------------------------------------------------------------------------------
 
-void two (uint32_t *z, const uint32_t *x)
+void two (int32_t *z, const int32_t *x)
 {
     (*z) = (double) (((*x) == 2) ? 1 : 0) ;
 }
@@ -76,6 +80,7 @@ void two (uint32_t *z, const uint32_t *x)
 // tricount: count the number of triangles in a graph
 //------------------------------------------------------------------------------
 
+GB_PUBLIC
 GrB_Info tricount           // count # of triangles
 (
     int64_t *p_ntri,        // # of trianagles
@@ -102,22 +107,25 @@ GrB_Info tricount           // count # of triangles
     GrB_Descriptor d = NULL ;
     OK (GrB_Descriptor_new (&d)) ;
 
+    GrB_Semiring semiring = GrB_PLUS_TIMES_SEMIRING_INT32 ;
+    GrB_Type ctype = GrB_INT32 ;
+
     switch (method)
     {
         case 0:  // minitri:    ntri = nnz (A*E == 2) / 3
 
             OK (GrB_Matrix_nrows (&n, A)) ;
             OK (GrB_Matrix_ncols (&ne, E)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, ne)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, ne)) ;
             // mxm:  outer product method, no mask
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_GUSTAVSON)) ;
             OK (GrB_mxm (C, NULL, NULL, GxB_PLUS_TIMES_UINT32, A, E, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_UnaryOp_new (&Two, two, GrB_UINT32, GrB_UINT32)) ;
-            OK (GrB_Matrix_new (&S, GrB_UINT32, n, ne)) ;
+            OK (GrB_UnaryOp_new (&Two, (GxB_unary_function) two, ctype, ctype));
+            OK (GrB_Matrix_new (&S, ctype, n, ne)) ;
             OK (GrB_Matrix_apply (S, NULL, NULL, Two, C, NULL)) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 S, NULL)) ;
             ntri /= 3 ;
             break ;
@@ -125,13 +133,13 @@ GrB_Info tricount           // count # of triangles
         case 1:  // Burkhardt:  ntri = sum (sum ((A^2) .* A)) / 6
 
             OK (GrB_Matrix_nrows (&n, A)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, n)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, n)) ;
             // mxm:  outer product method, with mask
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_GUSTAVSON)) ;
-            OK (GrB_mxm (C, A, NULL, GxB_PLUS_TIMES_UINT32, A, A, d)) ;
+            OK (GrB_mxm (C, A, NULL, semiring, A, A, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 C, NULL)) ;
             ntri /= 6 ;
             break ;
@@ -139,13 +147,13 @@ GrB_Info tricount           // count # of triangles
         case 2:  // Cohen:      ntri = sum (sum ((L * U) .* A)) / 2
 
             OK (GrB_Matrix_nrows (&n, A)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, n)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, n)) ;
             // mxm:  outer product method, with mask
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_GUSTAVSON)) ;
-            OK (GrB_mxm (C, A, NULL, GxB_PLUS_TIMES_UINT32, L, U, d)) ;
+            OK (GrB_mxm (C, A, NULL, semiring, L, U, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 C, NULL)) ;
             ntri /= 2 ;
             break ;
@@ -153,55 +161,55 @@ GrB_Info tricount           // count # of triangles
         case 3:  // Sandia:    ntri = sum (sum ((L * L) .* L))
 
             OK (GrB_Matrix_nrows (&n, L)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, n)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, n)) ;
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_GUSTAVSON)) ;
-            OK (GrB_mxm (C, L, NULL, GxB_PLUS_TIMES_UINT32, L, L, d)) ;
+            OK (GrB_mxm (C, L, NULL, semiring, L, L, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 C, NULL)) ;
             break ;
 
         case 4:  // Sandia2:    ntri = sum (sum ((U * U) .* U))
 
             OK (GrB_Matrix_nrows (&n, U)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, n)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, n)) ;
             // mxm:  outer product method, with mask
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_GUSTAVSON)) ;
-            OK (GrB_mxm (C, U, NULL, GxB_PLUS_TIMES_UINT32, U, U, d)) ;
+            OK (GrB_mxm (C, U, NULL, semiring, U, U, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 C, NULL)) ;
             break ;
 
         case 5:  // SandiaDot:  ntri = sum (sum ((L * U') .* L))
 
             OK (GrB_Matrix_nrows (&n, U)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, n)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, n)) ;
             OK (GrB_Descriptor_new (&d)) ;
             OK (GxB_Desc_set (d, GrB_INP1, GrB_TRAN)) ;
             // mxm:  dot product method, with mask
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_DOT)) ;
-            OK (GrB_mxm (C, L, NULL, GxB_PLUS_TIMES_UINT32, L, U, d)) ;
+            OK (GrB_mxm (C, L, NULL, semiring, L, U, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 C, NULL)) ;
             break ;
 
         case 6:  // SandiaDot2: ntri = sum (sum ((U * L') .* U))
 
             OK (GrB_Matrix_nrows (&n, U)) ;
-            OK (GrB_Matrix_new (&C, GrB_UINT32, n, n)) ;
+            OK (GrB_Matrix_new (&C, ctype, n, n)) ;
             OK (GrB_Descriptor_new (&d)) ;
             OK (GxB_Desc_set (d, GrB_INP1, GrB_TRAN)) ;
             // mxm:  dot product method, with mask
             OK (GxB_Desc_set (d, GxB_AxB_METHOD, GxB_AxB_DOT)) ;
-            OK (GrB_mxm (C, U, NULL, GxB_PLUS_TIMES_UINT32, U, L, d)) ;
+            OK (GrB_mxm (C, U, NULL, semiring, U, L, d)) ;
             t [0] = simple_toc (tic) ;
             simple_tic (tic) ;
-            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GxB_PLUS_INT64_MONOID,
+            OK (GrB_Matrix_reduce_INT64 (&ntri, NULL, GrB_PLUS_MONOID_INT64,
                 C, NULL)) ;
             break ;
 
