@@ -4,14 +4,16 @@ function display (G) %#ok<DISPLAY>
 % GraphBLAS sparse matrix object.  Use disp(G,3) to display all of the
 % content of G.
 %
-% See also disp.
+% See also GrB/disp.
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 name = inputname (1) ;
 if (~isempty (name))
     fprintf ('\n%s =\n', name) ;
 end
-gbdisp (G.opaque, nnz (G), 2) ;
+G = G.opaque ;
+gbdisp (G, gb_nnz (G), 2) ;
+fprintf ('\n') ;
 
