@@ -1,6 +1,5 @@
-function s = norm (G,kind)
-%NORM norm of a GraphBLAS sparse matrix.
-%
+function s = norm (G, kind)
+%NORM matrix or vector norm.
 % If G is a matrix:
 %
 %   norm (G,1) is the maximum sum of the columns of abs (G).
@@ -17,19 +16,25 @@ function s = norm (G,kind)
 %   norm (G,inf) is the maximum of abs (G)
 %   norm (G,-inf) is the minimum of abs (G)
 %
+% The p-norm for vectors is not yet supported.
+%
 % See also GrB.reduce, GrB.normdiff.
 
-% FUTURE: the p-norm is not yet supported.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% FUTURE: add the p-norm for vectors.
 
-if (nargin == 1)
-    kind = 2 ;
+if (isobject (G))
+    G = G.opaque ;
 end
 
-if (isa (G, 'GrB'))
-    G = G.opaque ;
+if (nargin == 2)
+    if (~ischar (kind))
+        kind = gb_get_scalar (kind) ;
+    end
+else
+    kind = 2 ;
 end
 
 s = gbnorm (G, kind) ;
