@@ -1,4 +1,4 @@
-function Cout = gbassign (Cin, M, accum, A, I, J, desc)     %#ok
+function C = gbassign (Cin, M, accum, A, I, J, desc)     %#ok
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
