@@ -1,4 +1,4 @@
-function Cout = gbeadd (Cin, M, accum, semiring, A, B, desc)        %#ok
+function C = gbeadd (Cin, M, accum, semiring, A, B, desc)        %#ok
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
