@@ -1,6 +1,6 @@
-function Cout = gbkronecker (Cin, M, accum, op, A, B, desc)
+function C = gbkronecker (Cin, M, accum, op, A, B, desc)     %#ok
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
 
 error ('GrB:mex', 'mexFunction not found; use gbmake to compile GraphBLAS') ;
