@@ -1,4 +1,4 @@
-function Cout = gblogassign (Cin, M, A)     %#ok
+function C = gblogassign (Cin, M, A)     %#ok
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
