@@ -1,4 +1,4 @@
-function cout = gbreduce (cin, accum, op, A, desc)      %#ok
+function c = gbreduce (cin, accum, op, A, desc)      %#ok
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
