@@ -1,4 +1,4 @@
-function Cout = gbsubassign (Cin, M, accum, A, I, j, desc)      %#ok
+function C = gbsubassign (Cin, M, accum, A, I, j, desc)      %#ok
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
