@@ -1,4 +1,4 @@
-function Cout = gbvreduce (Cin, M, accum, op, A, desc)      %#ok
+function C = gbvreduce (Cin, M, accum, op, A, desc)      %#ok
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 % http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
