@@ -10,6 +10,10 @@
 // The input may be either a GraphBLAS matrix struct or a standard MATLAB
 // sparse matrix.
 
+// Usage
+
+// nvals = gbnvals (X)
+
 #include "gb_matlab.h"
 
 void mexFunction
@@ -25,7 +29,7 @@ void mexFunction
     // check inputs
     //--------------------------------------------------------------------------
 
-    gb_usage (nargin == 1 && nargout <= 1, "usage: nvals = GrB.nvals (X)") ;
+    gb_usage (nargin == 1 && nargout <= 1, "usage: nvals = gbnvals (X)") ;
 
     //--------------------------------------------------------------------------
     // get the # of entries in the matrix
