@@ -27,7 +27,7 @@ void mexFunction
     // check inputs
     //--------------------------------------------------------------------------
 
-    gb_usage (nargin <= 2 && nargout == 0,
+    gb_usage (nargin >= 1 && nargin <= 2 && nargout == 0,
         "usage: GrB.unopinfo (unop) or GrB.unopinfo (unop,type)") ;
 
     //--------------------------------------------------------------------------
