@@ -30,6 +30,7 @@ GrB_Matrix gb_by_col            // return the matrix by column
         // make a deep copy of A_input and change it to be stored by column
         OK (GrB_Matrix_dup (&A_copy, A_input)) ;
         OK (GxB_Matrix_Option_set (A_copy, GxB_FORMAT, GxB_BY_COL)) ;
+        OK (GrB_Matrix_wait (&A_copy)) ;
         A = A_copy ;
     }
     else
@@ -38,10 +39,6 @@ GrB_Matrix gb_by_col            // return the matrix by column
         A = A_input ;
     }
 
-    // make sure A is finalized
-    GrB_Index anz ;
-    OK (GrB_Matrix_nvals (&anz, A)) ;
-
     // return results
     (*A_copy_handle) = A_copy ;
     return (A) ;
