@@ -2,7 +2,7 @@
 // gb_mxfree: mxFree wrapper
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 // http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
 
 //------------------------------------------------------------------------------
@@ -24,7 +24,7 @@ void gb_mxfree              // mxFree wrapper
     {
         if (*p_handle != NULL)
         { 
-            // mxFree (*p_handle) ;
+            mxFree (*p_handle) ;
         }
         (*p_handle) = NULL ;
     }
