@@ -1,5 +1,5 @@
 function C = spones (G, type)
-%SPONES return pattern of GraphBLAS matrix.
+%SPONES return pattern of a sparse matrix.
 % C = spones (G) returns a matrix C with the same pattern as G, but with
 % all entries set to 1.  The behavior of spones (G) for a GrB matrix
 % differs from spones (A) for a MATLAB matrix A.  An explicit entry
@@ -7,22 +7,23 @@ function C = spones (G, type)
 % C(i,j)=1.  Explicit zero entries never appear in a MATLAB sparse
 % matrix.
 %
-% C = spones (G) returns C as the same type as G.
+% C = spones (G) returns C as the same type as G if G is real.
+% If G is complex, C has the underlying real type of G ('single' if
+% G is 'single complex', or 'double' if G is 'double complex').
+%
 % C = spones (G,type) returns C in the requested type ('double',
 % 'single', 'int8', ...).  For example, use C = spones (G, 'logical') to
 % return the pattern of G as a sparse logical matrix.
 %
-% See also spfun, GrB.apply.
+% See also GrB/spfun, GrB.apply.
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
+G = G.opaque ;
 if (nargin == 1)
-    C = GrB.apply ('1', G) ;
+    C = GrB (gb_spones (G)) ;
 else
-    if (~ischar (type))
-        gb_error ('type must be a string') ;
-    end
-    C = GrB.apply (['1.' type], G) ;
+    C = GrB (gb_spones (G, type)) ;
 end
 
