@@ -1,8 +1,8 @@
 function gbtest1
 %GBTEST1 test GrB
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 rng ('default') ;
 X = 100 * sprand (3, 4, 0.4) %#ok<*NOPRT>
@@ -47,8 +47,8 @@ for k = 1:length (types)
 
     Z = full (fix (X)) ;
     A = GrB (Z, 'by row', type) ;
-    Y = cast (Z, type) ;
-    assert (isequal (A, Y)) ;
+    Y = gbtest_cast (Z, type) ;
+    assert (gbtest_eq (A, Y)) ;
 
 end
 
