@@ -1,15 +1,15 @@
 function gbtest20
 %GBTEST20 test bandwidth, isdiag, ceil, floor, round, fix
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 rng ('default') ;
 for trial = 1:10
     fprintf ('.') ;
     for m = 0:10
         for n = 0:10
-            A = 100 * sprand (m, n, 0.5) ;
+            A = 100 * sprandn (m, n, 0.5) ;
             G = GrB (A) ;
             [lo1, hi1] = bandwidth (A) ;
             [lo2, hi2] = bandwidth (G) ;
@@ -19,6 +19,7 @@ for trial = 1:10
             d2 = isdiag (G) ;
             assert (isequal (d1, d2)) ;
 
+            assert (gbtest_eq (sign  (A), sign  (G))) ;
             assert (gbtest_eq (ceil  (A), ceil  (G))) ;
             assert (gbtest_eq (floor (A), floor (G))) ;
             assert (gbtest_eq (round (A), round (G))) ;
