@@ -1,8 +1,8 @@
 function gbtest28
 %GBTEST28 test GrB.build
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 fprintf ('\ngbtest28: testing GrB.build and compare with A=sparse(i,j,x)\n') ;
 nthreads = GrB.threads ;
@@ -30,7 +30,7 @@ A = kron (A,B) ;
 clear B
 t = toc ;
 n = size (A, 1) ;
-fprintf ('%12.4f sec : A n-by-n, whth n: %g nnz: %g\n', t, n, nnz (A)) ;
+fprintf ('%12.4f sec : A n-by-n, with n: %g nnz: %g\n', t, n, nnz (A)) ;
 
 [i, j, x] = find (A) ;
 [m, n] = size (A) ;
