@@ -1,8 +1,8 @@
 function gbtest41
 %GBTEST41 test ones, zeros, false
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 types = gbtest_types ;
 
@@ -14,12 +14,12 @@ for trial = 1:40
         G = GrB (rand (2), type) ;
 
         G2 = ones (3, 4, 'like', G) ;
-        G3 = GrB (ones (3, 4, type)) ;
+        G3 = GrB (ones (3, 4), type) ;
         assert (gbtest_eq (G2, G3)) ;
 
         G1 = zeros ([3, 4], 'like', G) ;
         G2 = zeros (3, 4, 'like', G) ;
-        G3 = GrB (zeros (3, 4, type)) ;
+        G3 = GrB (zeros (3, 4), type) ;
 
         assert (isequal (G1, G2)) ;
         assert (isequal (GrB.type (G2), GrB.type (G3))) ;
@@ -28,7 +28,7 @@ for trial = 1:40
 
         if (isequal (type, 'logical'))
             G2 = false (3, 4, 'like', G) ;
-            G3 = GrB (false (3, 4, type)) ;
+            G3 = GrB (false (3, 4)) ;
             assert (isequal (GrB.type (G2), GrB.type (G3))) ;
             assert (isequal (type, GrB.type (G3))) ;
             assert (norm (double (G2) - double (G3), 1) == 0) ;
