@@ -1,8 +1,8 @@
 function gbtest51
 %GBTEST51 test GrB.tricount
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 files =  {
 '../../Demo/Matrix/2blocks'
@@ -39,7 +39,7 @@ valid_count = [
            0
          120 ] ;
 
-[filepath, name, ext] = fileparts (mfilename ('fullpath')) ;
+[filepath, name, ext] = fileparts (mfilename ('fullpath')) ; %#ok<*ASGLU>
 
 for k = 1:nfiles
     filename = files {k} ;
@@ -47,7 +47,7 @@ for k = 1:nfiles
     G = GrB.build (int64 (T (:,1)), int64 (T (:,2)), T (:,3), desc) ;
     [m, n] = size (G) ;
     if (m ~= n)
-        G = [GrB(m,m) G ; G' GrB(n,n)] ;
+        G = [GrB(m,m) G ; G' GrB(n,n)] ; %#ok<*AGROW>
     elseif (~issymmetric (G))
         G = G + G' ;
     end
