@@ -1,15 +1,17 @@
 function gbtest7
 %GBTEST7 test GrB.build
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
+
+rng ('default') ;
 
 n = 5 ;
 A = sprand (n, n, 0.5) ;
 A (n,n) = 5 ;
 
-[i j x] = find (A) ;
-[m n] = size (A) ;
+[i, j, x] = find (A) ;
+[m, n] = size (A) ;
 
 G = GrB.build (i, j, x, m, n) ;
 S = sparse   (i, j, x, m, n) ;
@@ -41,8 +43,10 @@ assert (isequal (speye (3), G)) ;
 types = gbtest_types ;
 for k = 1: length(types)
     type = types {k} ;
-    G = GrB.build (1:3, 1:3, cast (1, type)) ;
-    assert (isequal (speye (3), double (G))) ;
+    X = full (gbtest_cast (1, type)) ;
+    G = GrB.build (1:3, 1:3, X) ;
+    S = gbtest_cast (eye (3, 3), type) ;
+    assert (gbtest_eq (S, G)) ;
     assert (isequal (GrB.type (G), type)) ;
 end
 
