@@ -1,9 +1,8 @@
 function gbtest70
 %GBTEST70 test GrB.random
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
-% http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
-
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights
+% Reserved. http://suitesparse.com.  See GraphBLAS/Doc/License.txt.
 
 rng ('default') ; A = sprand (4, 5, 0.5) ;
 rng ('default') ; C0 = sprand (A) ;
@@ -20,7 +19,7 @@ for k = 1:length(types)
     rng ('default') ;
     G = GrB.random (30, 40, 0.6) ; %#ok<*NASGU>
 
-    r = cast ([3 40], type) ;
+    r = gbtest_cast ([3 40], type) ;
     G = GrB.random (300, 400, 0.6, 'range', r) ;
     assert (isequal (GrB.type (G), type)) ;
 
@@ -29,7 +28,7 @@ for k = 1:length(types)
         if (isinteger (r))
             assert (min (r) == min (r)) ;
             assert (max (r) == max (r)) ;
-        else
+        elseif (isreal (r))
             d = min (x) - min (r) ; assert (d > 0 && d < 0.01) ;
             d = max (r) - max (x) ; assert (d > 0 && d < 0.01) ;
         end
@@ -72,22 +71,16 @@ for k = 1:length(types)
     assert (issymmetric (G)) ;
     assert (isequal (GrB.type (G), type)) ;
 
+    G = GrB.random (30, 0.6, 'normal', 'range', r, 'hermitian') ;
+    assert (ishermitian (G)) ;
+    assert (isequal (GrB.type (G), type)) ;
+
     S = sprandsym (30, 0.6) ;
     G = sprandsym (GrB (S)) ;
     assert (isequal (spones (G), spones (S))) ;
     assert (issymmetric (G)) ;
     assert (isequal (GrB.type (G), 'double')) ;
 
-    G = sprandsym (GrB (S), 'uniform') ;
-    assert (isequal (spones (G), spones (S))) ;
-    assert (issymmetric (G)) ;
-    assert (isequal (GrB.type (G), 'double')) ;
-
-    G = sprandsym (GrB (S), 'normal') ;
-    assert (isequal (spones (G), spones (S))) ;
-    assert (issymmetric (G)) ;
-    assert (isequal (GrB.type (G), 'double')) ;
-
     S = sprandn (30, 40, 0.6) ;
     G = sprandn (GrB (S)) ;
     assert (isequal (spones (G), spones (S))) ;
@@ -98,6 +91,42 @@ for k = 1:length(types)
     assert (isequal (spones (G), spones (S))) ;
     assert (isequal (GrB.type (G), 'double')) ;
 
+    G = sprand (10, 12, GrB (0.5)) ;
+    assert (isequal (GrB.type (G), 'double')) ;
+    assert (isa (G, 'GrB')) ;
+    assert (isequal (size (G), [10 12])) ;
+
+    G = sprandn (10, 12, GrB (0.5)) ;
+    assert (isequal (GrB.type (G), 'double')) ;
+    assert (isa (G, 'GrB')) ;
+    assert (isequal (size (G), [10 12])) ;
+    gnz = nnz (G) ;
+    % nnz (G) is hard to predict because of duplicates
+    assert (abs (10*12*0.5 - gnz) < 30) ;
+
+    G = sprandn (10, 12, GrB (inf)) ;
+    assert (isequal (GrB.type (G), 'double')) ;
+    assert (isa (G, 'GrB')) ;
+    assert (isequal (size (G), [10 12])) ;
+    assert (nnz (G) == 120) ;
+
+    G = sprandsym (10, GrB (0.5)) ;
+    assert (isequal (GrB.type (G), 'double')) ;
+    assert (isa (G, 'GrB')) ;
+    assert (isequal (size (G), [10 10])) ;
+    gnz = nnz (G) ;
+    assert (abs (10*10*0.5 - gnz) < 30) ;
+
+    G = sprandsym (10, GrB (inf)) ;
+    assert (isequal (GrB.type (G), 'double')) ;
+    assert (isa (G, 'GrB')) ;
+    assert (isequal (size (G), [10 10])) ;
+    assert (nnz (G) == 100)
+    assert (GrB.isfull (G)) ;
+    assert (GrB.isfull (double (G))) ;
+    assert (GrB.isfull (full (G))) ;
+    assert (GrB.isfull (full (double (G)))) ;
+
 end
 
 
