@@ -59,7 +59,7 @@
 // table size for the task, and C is m-by-n (assuming all matrices are CSC; if
 // CSR, then m is replaced with n).
 //
-//      fine Gustavson task (shared):   uint8_t Hf [m] ; ctype Hx [m] ;
+//      fine Gustavson task (shared):   int8_t  Hf [m] ; ctype Hx [m] ;
 //      fine hash task (shared):        int64_t Hf [s] ; ctype Hx [s] ;
 //      coarse Gustavson task:          int64_t Hf [m] ; ctype Hx [m] ;
 //      coarse hash task:               int64_t Hf [s] ; ctype Hx [s] ;
@@ -85,6 +85,7 @@
 
 #include "GB_mxm.h"
 #include "GB_AxB_saxpy3.h"
+#include "GB_mkl.h"
 #ifndef GBCOMPACT
 #include "GB_AxB__include.h"
 #endif
@@ -105,18 +106,19 @@
 // This workspace is not needed in the GB_Asaxpy3B* worker functions.
 #define GB_FREE_INITIAL_WORK                                                \
 {                                                                           \
-    GB_FREE_MEMORY (Bflops2, max_bjnz+1, sizeof (int64_t)) ;                \
-    GB_FREE_MEMORY (Coarse_initial, ntasks_initial+1, sizeof (int64_t)) ;   \
-    GB_FREE_MEMORY (Fine_slice, ntasks+1, sizeof (int64_t)) ;               \
+    GB_FREE (Bflops2) ;                                                     \
+    GB_FREE (Coarse_Work) ;                                                 \
+    GB_FREE (Coarse_initial) ;                                              \
+    GB_FREE (Fine_slice) ;                                                  \
 }
 
 #define GB_FREE_WORK                                                        \
 {                                                                           \
     GB_FREE_INITIAL_WORK ;                                                  \
-    GB_FREE_MEMORY (TaskList, ntasks, sizeof (GB_saxpy3task_struct)) ;      \
-    GB_FREE_MEMORY (Hi_all, Hi_size_total, sizeof (int64_t)) ;              \
-    GB_FREE_MEMORY (Hf_all, Hf_size_total, sizeof (int64_t)) ;              \
-    GB_FREE_MEMORY (Hx_all, Hx_size_total, 1) ;                             \
+    GB_FREE (TaskList) ;                                                    \
+    GB_FREE (Hi_all) ;                                                      \
+    GB_FREE (Hf_all) ;                                                      \
+    GB_FREE (Hx_all) ;                                                      \
 }
 
 #define GB_FREE_ALL                                                         \
@@ -195,20 +197,48 @@ static inline void GB_create_coarse_task
     int64_t cvlen,      // vector length of B and C
     double chunk,
     int nthreads_max,
+    int64_t *Coarse_Work,   // workspace for parallel reduction for flop count
     const GrB_Desc_Value AxB_method     // Default, Gustavson, or Hash
 )
 {
     // find the max # of flops for any vector in this task
-    int64_t flmax = 1 ;
-    int nth = GB_nthreads (klast-kfirst+1, chunk, nthreads_max) ;
-    int64_t kk ;
-    #pragma omp parallel for num_threads(nth) schedule(static) \
-        reduction(max:flmax)
-    for (kk = kfirst ; kk <= klast ; kk++)
-    { 
-        int64_t fl = Bflops [kk+1] - Bflops [kk] ;
-        flmax = GB_IMAX (flmax, fl) ;
+    int64_t nk = klast - kfirst + 1 ;
+    int nth = GB_nthreads (nk, chunk, nthreads_max) ;
+    int64_t tid ;
+
+    // each thread finds the max flop count for a subset of the vectors
+    #pragma omp parallel for num_threads(nth) schedule(static)
+    for (tid = 0 ; tid < nth ; tid++)
+    {
+        int64_t my_flmax = 1, istart, iend ;
+        GB_PARTITION (istart, iend, nk, tid, nth) ;
+        for (int64_t i = istart ; i < iend ; i++)
+        {
+            int64_t kk = kfirst + i ;
+            int64_t fl = Bflops [kk+1] - Bflops [kk] ;
+            my_flmax = GB_IMAX (my_flmax, fl) ;
+        }
+        Coarse_Work [tid] = my_flmax ;
     }
+
+    // combine results from each thread
+    int64_t flmax = 1 ;
+    for (tid = 0 ; tid < nth ; tid++)
+    {
+        flmax = GB_IMAX (flmax, Coarse_Work [tid]) ;
+    }
+
+    // check the parallel computation
+    #ifdef GB_DEBUG
+    int64_t flmax2 = 1 ;
+    for (int64_t kk = kfirst ; kk <= klast ; kk++)
+    {
+        int64_t fl = Bflops [kk+1] - Bflops [kk] ;
+        flmax2 = GB_IMAX (flmax2, fl) ;
+    }
+    ASSERT (flmax == flmax2) ;
+    #endif
+
     // define the coarse task
     TaskList [taskid].start   = kfirst ;
     TaskList [taskid].end     = klast ;
@@ -263,10 +293,61 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     ASSERT_SEMIRING_OK (semiring, "semiring for saxpy3 A*B", GB0) ;
     ASSERT (A->vdim == B->vlen) ;
 
+    (*Chandle) = NULL ;
+
+    //--------------------------------------------------------------------------
+    // determine the # of threads to use, and the use_mkl flag
+    //--------------------------------------------------------------------------
+
+    GB_GET_NTHREADS_MAX (nthreads_max, chunk, Context) ;
+    bool use_mkl = (Context == NULL) ? false : Context->use_mkl ;
+
+    //--------------------------------------------------------------------------
+    // use MKL_graph if it available and has this semiring
+    //--------------------------------------------------------------------------
+
+    // Note that GB_AxB_saxpy3 computes C=A*B where A and B treated as if CSC,
+    // but MKL views the matrices as CSR.  So they are flipped below:
+
+    #if GB_HAS_MKL_GRAPH
+
+    if (use_mkl)
+    {
+        info = GB_AxB_saxpy3_mkl (
+            Chandle,            // output matrix to construct
+            M,                  // input mask M (may be NULL)
+            Mask_comp,          // true if M is complemented
+            Mask_struct,        // true if M is structural
+            B,                  // first input matrix
+            A,                  // second input matrix
+            semiring,           // semiring that defines C=A*B
+            !flipxy,            // true if multiply operator is flipped
+            mask_applied,       // if true, then mask was applied
+            Context) ;
+
+        if (info != GrB_NO_VALUE)
+        {
+            // MKL_graph supports this semiring, and has ether computed C=A*B,
+            // C<M>=A*B, or C<!M>=A*B, or has failed.
+            return (info) ;
+        }
+
+        GBBURBLE ("(MKL tried) ") ;
+
+        // If MKL_graph doesn't support this semiring, it returns GrB_NO_VALUE,
+        // so fall through to use GraphBLAS, below.
+    }
+    #endif
+
+    //--------------------------------------------------------------------------
+    // define workspace
+    //--------------------------------------------------------------------------
+
     int64_t *GB_RESTRICT Hi_all = NULL ;
     int64_t *GB_RESTRICT Hf_all = NULL ;
     GB_void *GB_RESTRICT Hx_all = NULL ;
     int64_t *GB_RESTRICT Coarse_initial = NULL ;    // initial coarse tasks
+    int64_t *GB_RESTRICT Coarse_Work = NULL ;       // workspace for flop counts
     GB_saxpy3task_struct *GB_RESTRICT TaskList = NULL ;
     int64_t *GB_RESTRICT Fine_slice = NULL ;
     int64_t *GB_RESTRICT Bflops2 = NULL ;
@@ -285,49 +366,22 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     GrB_BinaryOp mult = semiring->multiply ;
     GrB_Monoid add = semiring->add ;
     ASSERT (mult->ztype == add->op->ztype) ;
-
-    bool op_is_first  = mult->opcode == GB_FIRST_opcode ;
-    bool op_is_second = mult->opcode == GB_SECOND_opcode ;
-    bool op_is_pair   = mult->opcode == GB_PAIR_opcode ;
-    bool A_is_pattern = false ;
-    bool B_is_pattern = false ;
-
-    if (flipxy)
-    { 
-        // z = fmult (b,a) will be computed
-        A_is_pattern = op_is_first  || op_is_pair ;
-        B_is_pattern = op_is_second || op_is_pair ;
-        ASSERT (GB_IMPLIES (!A_is_pattern,
-            GB_Type_compatible (A->type, mult->ytype))) ;
-        ASSERT (GB_IMPLIES (!B_is_pattern,
-            GB_Type_compatible (B->type, mult->xtype))) ;
-    }
-    else
-    { 
-        // z = fmult (a,b) will be computed
-        A_is_pattern = op_is_second || op_is_pair ;
-        B_is_pattern = op_is_first  || op_is_pair ;
-        ASSERT (GB_IMPLIES (!A_is_pattern,
-            GB_Type_compatible (A->type, mult->xtype))) ;
-        ASSERT (GB_IMPLIES (!B_is_pattern,
-            GB_Type_compatible (B->type, mult->ytype))) ;
-    }
+    bool A_is_pattern, B_is_pattern ;
+    GB_AxB_pattern (&A_is_pattern, &B_is_pattern, flipxy, mult->opcode) ;
 
     #ifdef GBCOMPACT
     bool is_any_pair_semiring = false ;
     #else
     GB_Opcode mult_opcode, add_opcode ;
-    GB_Type_code xycode, zcode ;
+    GB_Type_code xcode, ycode, zcode ;
     bool builtin_semiring = GB_AxB_semiring_builtin (A, A_is_pattern, B,
-        B_is_pattern, semiring, flipxy, &mult_opcode, &add_opcode, &xycode,
-        &zcode) ;
+        B_is_pattern, semiring, flipxy, &mult_opcode, &add_opcode, &xcode,
+        &ycode, &zcode) ;
     bool is_any_pair_semiring = builtin_semiring
         && (add_opcode == GB_ANY_opcode)
         && (mult_opcode == GB_PAIR_opcode) ;
     #endif
 
-    (*Chandle) = NULL ;
-
     //--------------------------------------------------------------------------
     // get A, and B
     //--------------------------------------------------------------------------
@@ -347,12 +401,6 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     const int64_t bnvec = B->nvec ;
     const bool B_is_hyper = B->is_hyper ;
 
-    //--------------------------------------------------------------------------
-    // determine the # of threads to use
-    //--------------------------------------------------------------------------
-
-    GB_GET_NTHREADS_MAX (nthreads_max, chunk, Context) ;
-
     //--------------------------------------------------------------------------
     // allocate C (just C->p and C->h, but not C->i or C->x)
     //--------------------------------------------------------------------------
@@ -364,7 +412,7 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     int64_t cnvec = bnvec ;
 
     // calloc Cp so it can be used as the Bflops workspace
-    GB_NEW (Chandle, ctype, cvlen, cvdim, GB_Ap_calloc, true,
+    info = GB_new (Chandle, ctype, cvlen, cvdim, GB_Ap_calloc, true,
         GB_SAME_HYPER_AS (B_is_hyper), B->hyper_ratio, cnvec, Context) ;
     if (info != GrB_SUCCESS)
     { 
@@ -455,7 +503,7 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
         Mp = M->p ;
         Mh = M->h ;
         Mi = M->i ;
-        // Mx = M->x ;
+        // Mx = (GB_void *) (Mask_struct ? NULL : (M->x)) ;
         // msize = M->type->size ;
         mnvec = M->nvec ;
         M_is_hyper = M->is_hyper ;
@@ -595,15 +643,16 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     // allocate the tasks, and workspace to construct fine tasks
     //--------------------------------------------------------------------------
 
-    GB_CALLOC_MEMORY (TaskList, ntasks, sizeof (GB_saxpy3task_struct)) ;
+    TaskList    = GB_CALLOC (ntasks, GB_saxpy3task_struct) ;
+    Coarse_Work = GB_MALLOC (nthreads_max, int64_t) ;
     if (max_bjnz > 0)
     { 
         // also allocate workspace to construct fine tasks
-        GB_MALLOC_MEMORY (Fine_slice, ntasks+1, sizeof (int64_t)) ;
-        GB_MALLOC_MEMORY (Bflops2, max_bjnz+1, sizeof (int64_t)) ;
+        Fine_slice = GB_MALLOC (ntasks+1  , int64_t) ;
+        Bflops2    = GB_MALLOC (max_bjnz+1, int64_t) ;
     }
 
-    if (TaskList == NULL ||
+    if (TaskList == NULL || Coarse_Work == NULL ||
         (max_bjnz > 0 && (Fine_slice == NULL || Bflops2 == NULL)))
     { 
         // out of memory
@@ -662,7 +711,7 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
                             // kcoarse_start:kk-1 form a single coarse task
                             GB_create_coarse_task (kcoarse_start, kk-1,
                                 TaskList, nc++, Bflops, cvlen,
-                                chunk, nthreads_max, AxB_method) ;
+                                chunk, nthreads_max, Coarse_Work, AxB_method) ;
                         }
 
                         // next coarse task (if any) starts at kk+1
@@ -762,7 +811,8 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
                 { 
                     // kcoarse_start:klast-1 form a single coarse task
                     GB_create_coarse_task (kcoarse_start, klast-1, TaskList,
-                        nc++, Bflops, cvlen, chunk, nthreads_max, AxB_method) ;
+                        nc++, Bflops, cvlen, chunk, nthreads_max, Coarse_Work,
+                        AxB_method) ;
                 }
 
             }
@@ -770,7 +820,7 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
             { 
                 // This coarse task is OK as-is.
                 GB_create_coarse_task (kfirst, klast-1, TaskList, nc++, Bflops,
-                    cvlen, chunk, nthreads_max, AxB_method) ;
+                    cvlen, chunk, nthreads_max, Coarse_Work, AxB_method) ;
             }
         }
 
@@ -784,7 +834,7 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
 
         // create a single coarse task
         GB_create_coarse_task (0, bnvec-1, TaskList, 0, Bflops, cvlen, 1, 1,
-            AxB_method) ;
+            Coarse_Work, AxB_method) ;
 
         if (bnvec == 1)
         { 
@@ -799,8 +849,8 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     // free workspace used to create the tasks
     //--------------------------------------------------------------------------
 
-    // Frees Bflops2, Coarse_initial, and Fine_slice.  These do not need to
-    // be freed in the GB_Asaxpy3B worker below.
+    // Frees Bflops2, Coarse_initial, Coarse_Work, and Fine_slice.  These do
+    // not need to be freed in the GB_Asaxpy3B worker below.
 
     GB_FREE_INITIAL_WORK ;
 
@@ -893,8 +943,8 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     // For both coarse methods:
     //
     //      Hf starts out all zero (via calloc), and mark starts out as 1.  To
-    //      clear all of Hf, mark is incremented, so that all entries in Hf are
-    //      not equal to mark.
+    //      clear Hf, mark is incremented, so that all entries in Hf are not
+    //      equal to mark.
 
     // add some padding to the end of each hash table, to avoid false
     // sharing of cache lines between the hash tables.
@@ -924,9 +974,9 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
 
         if (is_fine && use_Gustavson)
         { 
-            // Hf is uint8_t for the fine Gustavson tasks, but round up
+            // Hf is int8_t for the fine Gustavson tasks, but round up
             // to the nearest number of int64_t values.
-            Hf_size_total += GB_CEIL ((hash_size + hi_pad), sizeof (int64_t)) ;
+            Hf_size_total += GB_ICEIL ((hash_size + hi_pad), sizeof (int64_t)) ;
         }
         else
         { 
@@ -949,15 +999,15 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
     // allocate space for all hash tables
     if (Hi_size_total > 0)
     { 
-        GB_MALLOC_MEMORY (Hi_all, Hi_size_total, sizeof (int64_t)) ;
+        Hi_all = GB_MALLOC (Hi_size_total, int64_t) ;
     }
     if (Hf_size_total > 0)
     { 
-        GB_CALLOC_MEMORY (Hf_all, Hf_size_total, sizeof (int64_t)) ;
+        Hf_all = GB_CALLOC (Hf_size_total, int64_t) ;
     }
     if (Hx_size_total > 0)
     { 
-        GB_MALLOC_MEMORY (Hx_all, Hx_size_total, 1) ;
+        Hx_all = GB_MALLOC (Hx_size_total, GB_void) ;
     }
 
     if ((Hi_size_total > 0 && Hi_all == NULL) ||
@@ -984,7 +1034,7 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
         }
 
         TaskList [taskid].Hi = Hi_split ;
-        TaskList [taskid].Hf = (void *) Hf_split ;
+        TaskList [taskid].Hf = (GB_void *) Hf_split ;
         TaskList [taskid].Hx = Hx_split ;
 
         int64_t hash_size = TaskList [taskid].hsize ;
@@ -996,8 +1046,8 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
 
         if (is_fine && use_Gustavson)
         { 
-            // Hf is uint8_t for the fine Gustavson method
-            Hf_split += GB_CEIL ((hash_size + hi_pad), sizeof (int64_t)) ;
+            // Hf is int8_t for the fine Gustavson method
+            Hf_split += GB_ICEIL ((hash_size + hi_pad), sizeof (int64_t)) ;
         }
         else
         { 
@@ -1044,33 +1094,34 @@ GrB_Info GB_AxB_saxpy3              // C = A*B using Gustavson+Hash
 
     bool done = false ;
 
-#ifndef GBCOMPACT
+    #ifndef GBCOMPACT
 
-    //--------------------------------------------------------------------------
-    // define the worker for the switch factory
-    //--------------------------------------------------------------------------
+        //----------------------------------------------------------------------
+        // define the worker for the switch factory
+        //----------------------------------------------------------------------
 
-    #define GB_Asaxpy3B(add,mult,xyname) GB_Asaxpy3B_ ## add ## mult ## xyname
+        #define GB_Asaxpy3B(add,mult,xname) \
+            GB_Asaxpy3B_ ## add ## mult ## xname
 
-    #define GB_AxB_WORKER(add,mult,xyname)                              \
-    {                                                                   \
-        info = GB_Asaxpy3B (add,mult,xyname) (C, M, Mask_comp,          \
-            Mask_struct, A, A_is_pattern, B, B_is_pattern,              \
-            TaskList, ntasks, nfine, nthreads, Context) ;               \
-        done = (info != GrB_NO_VALUE) ;                                 \
-    }                                                                   \
-    break ;
+        #define GB_AxB_WORKER(add,mult,xname)                               \
+        {                                                                   \
+            info = GB_Asaxpy3B (add,mult,xname) (C, M, Mask_comp,           \
+                Mask_struct, A, A_is_pattern, B, B_is_pattern,              \
+                TaskList, ntasks, nfine, nthreads, Context) ;               \
+            done = (info != GrB_NO_VALUE) ;                                 \
+        }                                                                   \
+        break ;
 
-    //--------------------------------------------------------------------------
-    // launch the switch factory
-    //--------------------------------------------------------------------------
+        //----------------------------------------------------------------------
+        // launch the switch factory
+        //----------------------------------------------------------------------
 
-    if (builtin_semiring)
-    { 
-        #include "GB_AxB_factory.c"
-    }
+        if (builtin_semiring)
+        { 
+            #include "GB_AxB_factory.c"
+        }
 
-#endif
+    #endif
 
     //==========================================================================
     // C = A*B, via the generic saxpy3 method, with typecasting
