@@ -2,7 +2,7 @@
 // GB_Index_multiply:  multiply two integers and guard against overflow
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2019, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2020, All Rights Reserved.
 // http://suitesparse.com   See GraphBLAS/Doc/License.txt for license.
 
 //------------------------------------------------------------------------------
@@ -14,7 +14,7 @@
 
 bool GB_Index_multiply      // true if ok, false if overflow
 (
-    GrB_Index *restrict c,  // c = a*b, or zero if overflow occurs
+    GrB_Index *GB_RESTRICT c,  // c = a*b, or zero if overflow occurs
     const int64_t a,
     const int64_t b
 )
@@ -28,7 +28,7 @@ bool GB_Index_multiply      // true if ok, false if overflow
         return (true) ;
     }
 
-    if (a < 0 || a > GB_INDEX_MAX || b < 0 || b > GB_INDEX_MAX)
+    if (a < 0 || a > GxB_INDEX_MAX || b < 0 || b > GxB_INDEX_MAX)
     { 
         // a or b are out of range
         return (false) ;
@@ -37,7 +37,7 @@ bool GB_Index_multiply      // true if ok, false if overflow
     double da = ceil (log2 ((double) a)) ;
     double db = ceil (log2 ((double) b)) ;
     if (da + db > 60)
-    {
+    { 
         // a * b may overflow
         return (false) ;
     }
