@@ -7,14 +7,14 @@
 
 //------------------------------------------------------------------------------
 
-#include "GB_printf.h"
+#include "GB.h"
 
+GB_PUBLIC   // accessed by the MATLAB tests in GraphBLAS/Test only
 GrB_Info GB_Monoid_check        // check a GraphBLAS monoid
 (
     const GrB_Monoid monoid,    // GraphBLAS monoid to print and check
     const char *name,           // name of the monoid, optional
-    int pr,                     // 0: print nothing, 1: print header and errors,
-                                // 2: print brief, 3: print all
+    int pr,                     // print level
     FILE *f,                    // file for output
     GB_Context Context
 )
@@ -38,21 +38,7 @@ GrB_Info GB_Monoid_check        // check a GraphBLAS monoid
     //--------------------------------------------------------------------------
 
     GB_CHECK_MAGIC (monoid, "Monoid") ;
-
-    switch (monoid->object_kind)
-    {
-        case GB_BUILTIN :
-            GBPR0 ("(built-in)") ;
-            break ;
-
-        case GB_USER_RUNTIME :
-            GBPR0 ("(user-defined)") ;
-            break ;
-
-        default :
-            return (GB_ERROR (GrB_INVALID_OBJECT, (GB_LOG,
-                "Monoid->object_kind is invalid: [%s]", GB_NAME))) ;
-    }
+    GBPR0 (monoid->builtin ? "(built-in)" : "(user-defined)") ;
 
     GrB_Info info = GB_BinaryOp_check (monoid->op, "monoid->op", pr, f,
         Context) ;
@@ -72,11 +58,11 @@ GrB_Info GB_Monoid_check        // check a GraphBLAS monoid
             GB_NAME))) ;
     }
 
-    // print the identity value
-    if (pr > 0)
+    // print the identity and terminal values
+    if (pr != GxB_SILENT)
     { 
         GBPR ("    identity: [ ") ;
-        info = GB_entry_check (monoid->op->ztype, monoid->identity, f,  
+        info = GB_entry_check (monoid->op->ztype, monoid->identity, pr, f,
             Context) ;
         if (info != GrB_SUCCESS) return (info) ;
         GBPR (" ] ") ;
@@ -84,7 +70,7 @@ GrB_Info GB_Monoid_check        // check a GraphBLAS monoid
         if (monoid->terminal != NULL)
         { 
             GBPR ("terminal: [ ") ;
-            info = GB_entry_check (monoid->op->ztype, monoid->terminal, f,  
+            info = GB_entry_check (monoid->op->ztype, monoid->terminal, pr, f,  
                 Context) ;
             if (info != GrB_SUCCESS) return (info) ;
             GBPR (" ]") ;
