@@ -30,8 +30,7 @@ bool GB_Pending_alloc       // create a list of pending tuples
     // allocate the Pending header
     //--------------------------------------------------------------------------
 
-    GB_Pending Pending ;
-    GB_CALLOC_MEMORY (Pending, 1, sizeof (struct GB_Pending_struct)) ;
+    GB_Pending Pending = GB_CALLOC (1, struct GB_Pending_struct) ;
     if (Pending == NULL)
     { 
         // out of memory
@@ -50,18 +49,18 @@ bool GB_Pending_alloc       // create a list of pending tuples
     Pending->size = type->size ;        // size of pending tuple type
     Pending->op = op ;                  // pending operator (NULL is OK)
 
-    GB_MALLOC_MEMORY (Pending->i, nmax, sizeof (int64_t)) ;
+    Pending->i = GB_MALLOC (nmax, int64_t) ;
 
     if (is_matrix)
     { 
-        GB_MALLOC_MEMORY (Pending->j, nmax, sizeof (int64_t)) ;
+        Pending->j = GB_MALLOC (nmax, int64_t) ;
     }
     else
     { 
         Pending->j = NULL ;
     }
 
-    GB_MALLOC_MEMORY (Pending->x, nmax, Pending->size) ;
+    Pending->x = GB_MALLOC (nmax * Pending->size, GB_void) ;
 
     if (Pending->i == NULL || Pending->x == NULL
         || (is_matrix && Pending->j == NULL))
