@@ -28,10 +28,10 @@ void GB_Pending_free        // free a list of pending tuples
     GB_Pending Pending = (*PHandle) ;
     if (Pending != NULL)
     { 
-        GB_FREE_MEMORY (Pending->i, Pending->nmax, sizeof (int64_t)) ;
-        GB_FREE_MEMORY (Pending->j, Pending->nmax, sizeof (int64_t)) ;
-        GB_FREE_MEMORY (Pending->x, Pending->nmax, Pending->size) ;
-        GB_FREE_MEMORY (Pending, 1, sizeof (struct GB_Pending_struct)) ;
+        GB_FREE (Pending->i) ;
+        GB_FREE (Pending->j) ;
+        GB_FREE (Pending->x) ;
+        GB_FREE (Pending) ;
     }
 
     (*PHandle) = NULL ;
