@@ -7,14 +7,14 @@
 
 //------------------------------------------------------------------------------
 
-#include "GB_printf.h"
+#include "GB.h"
 
+GB_PUBLIC   // accessed by the MATLAB tests in GraphBLAS/Test only
 GrB_Info GB_SelectOp_check  // check a GraphBLAS select operator
 (
     const GxB_SelectOp op,  // GraphBLAS operator to print and check
     const char *name,       // name of the operator
-    int pr,                 // 0: print nothing, 1: print header and errors,
-                            // 2: print brief, 3: print all
+    int pr,                 // print level
     FILE *f,                // file for output
     GB_Context Context
 )
@@ -39,16 +39,13 @@ GrB_Info GB_SelectOp_check  // check a GraphBLAS select operator
 
     GB_CHECK_MAGIC (op, "SelectOp") ;
 
-    if (pr > 0)
-    {
-        if (op->opcode >= GB_USER_SELECT_opcode)
-        { 
-            GBPR ("(user-defined) ") ;
-        }
-        else
-        { 
-            GBPR ("(built-in) ") ;
-        }
+    if (op->opcode >= GB_USER_SELECT_opcode)
+    { 
+        GBPR0 ("(user-defined) ") ;
+    }
+    else
+    { 
+        GBPR0 ("(built-in) ") ;
     }
 
     GBPR0 ("C=%s(A,k)\n", op->name) ;
