@@ -12,14 +12,14 @@
 // matrix A:", for example.  The internal name is the C typedef with which the
 // GraphBLAS GrB_Type was created.
 
-#include "GB_printf.h"
+#include "GB.h"
 
+GB_PUBLIC   // accessed by the MATLAB tests in GraphBLAS/Test only
 GrB_Info GB_Type_check      // check a GraphBLAS Type
 (
     const GrB_Type type,    // GraphBLAS type to print and check
     const char *name,       // name of the type from the caller; optional
-    int pr,                 // 0: print nothing, 1: print header and errors,
-                            // 2: print brief, 3: print all
+    int pr,                 // print level
     FILE *f,                // file for output
     GB_Context Context
 )
@@ -30,7 +30,7 @@ GrB_Info GB_Type_check      // check a GraphBLAS Type
     //--------------------------------------------------------------------------
 
     GBPR0 ("    GraphBLAS type: ") ;
-    if (pr > 0 && name != NULL) GBPR ("%s ", name) ;
+    if (name != NULL) GBPR0 ("%s ", name) ;
 
     if (type == NULL)
     { 
@@ -58,6 +58,8 @@ GrB_Info GB_Type_check      // check a GraphBLAS Type
         case GB_UINT64_code : GBPR0 ("uint64_t" ) ; break ;
         case GB_FP32_code   : GBPR0 ("float"    ) ; break ;
         case GB_FP64_code   : GBPR0 ("double"   ) ; break ;
+        case GB_FC32_code   : GBPR0 ("float complex" ) ; break ;
+        case GB_FC64_code   : GBPR0 ("double complex") ; break ;
         case GB_UDT_code    : GBPR0 ("user-defined: [%s]", type->name) ; break ;
         default             : GBPR0 ("unknown type\n") ;
             return (GB_ERROR (GrB_INVALID_OBJECT, (GB_LOG,
