@@ -14,6 +14,7 @@
 // This function is not directly user-callable.  Use GrB_UnaryOp_new instead.
 
 #include "GB.h"
+#include <ctype.h>
 
 GrB_Info GB_UnaryOp_new             // create a new user-defined unary operator
 (
@@ -41,7 +42,7 @@ GrB_Info GB_UnaryOp_new             // create a new user-defined unary operator
     //--------------------------------------------------------------------------
 
     // allocate the unary operator
-    GB_CALLOC_MEMORY (*unaryop, 1, sizeof (struct GB_UnaryOp_opaque)) ;
+    (*unaryop) = GB_CALLOC (1, struct GB_UnaryOp_opaque) ;
     if (*unaryop == NULL)
     { 
         // out of memory
@@ -54,8 +55,42 @@ GrB_Info GB_UnaryOp_new             // create a new user-defined unary operator
     op->xtype = xtype ;
     op->ztype = ztype ;
     op->function = function ;
-    strncpy (op->name, name, GB_LEN-1) ;
     op->opcode = GB_USER_opcode ;     // user-defined operator
+
+    //--------------------------------------------------------------------------
+    // find the name of the operator
+    //--------------------------------------------------------------------------
+
+    if (name == NULL)
+    { 
+        // if no name , a generic name is used instead
+        strncpy (op->name, "user_unary_operator", GB_LEN-1) ;
+    }
+    else
+    {
+        // see if the typecast "(GxB_unary_function)" appears in the name
+        char *p = NULL ;
+        p = strstr ((char *) name, "GxB_unary_function") ;
+        if (p != NULL)
+        { 
+            // skip past the typecast, the left parenthesis, and any whitespace
+            p += 19 ;
+            while (isspace (*p)) p++ ;
+            if (*p == ')') p++ ;
+            while (isspace (*p)) p++ ;
+            strncpy (op->name, p, GB_LEN-1) ;
+        }
+        else
+        { 
+            // copy the entire name as-is
+            strncpy (op->name, name, GB_LEN-1) ;
+        }
+    }
+
+    //--------------------------------------------------------------------------
+    // return result
+    //--------------------------------------------------------------------------
+
     ASSERT_UNARYOP_OK (op, "new user-defined unary op", GB0) ;
     return (GrB_SUCCESS) ;
 }
