@@ -29,16 +29,16 @@
 #include "GB_subref.h"
 #include "GB_transpose.h"
 
-#define GB_FREE_ALL                                     \
-{                                                       \
-    GB_MATRIX_FREE (&Z2) ;                              \
-    GB_MATRIX_FREE (&AT) ;                              \
-    GB_MATRIX_FREE (&MT) ;                              \
-    GB_FREE_MEMORY (I2,  I2_size, sizeof (GrB_Index)) ; \
-    GB_FREE_MEMORY (I2k, I2_size, sizeof (GrB_Index)) ; \
-    GB_FREE_MEMORY (J2,  J2_size, sizeof (GrB_Index)) ; \
-    GB_FREE_MEMORY (J2k, J2_size, sizeof (GrB_Index)) ; \
-    GB_MATRIX_FREE (&SubMask) ;                         \
+#define GB_FREE_ALL             \
+{                               \
+    GB_MATRIX_FREE (&Z2) ;      \
+    GB_MATRIX_FREE (&AT) ;      \
+    GB_MATRIX_FREE (&MT) ;      \
+    GB_FREE (I2) ;              \
+    GB_FREE (I2k) ;             \
+    GB_FREE (J2) ;              \
+    GB_FREE (J2k) ;             \
+    GB_MATRIX_FREE (&SubMask) ; \
 }
 
 GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
@@ -147,7 +147,7 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
         if (!GB_code_compatible (C->type->code, scalar_code))
         { 
             return (GB_ERROR (GrB_DOMAIN_MISMATCH, (GB_LOG,
-                "input scalar of type [%s]\n"
+                "Input scalar of type [%s]\n"
                 "cannot be typecast to output of type [%s]",
                 GB_code_string (scalar_code), C->type->name))) ;
         }
@@ -157,7 +157,7 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
         if (!GB_Type_compatible (C->type, A->type))
         { 
             return (GB_ERROR (GrB_DOMAIN_MISMATCH, (GB_LOG,
-                "input of type [%s]\n"
+                "Input of type [%s]\n"
                 "cannot be typecast to output of type [%s]",
                 A->type->name, C->type->name))) ;
         }
@@ -184,8 +184,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             if (GB_NROWS (M) != GB_NCOLS (C))
             { 
                 return (GB_ERROR (GrB_DIMENSION_MISMATCH, (GB_LOG,
-                    "mask vector m length is "GBd"; must match the number of "
-                    "columns of C ("GBd")", GB_NROWS (M), GB_NCOLS (C)))) ;
+                    "Mask vector m length is " GBd "; must match the number of "
+                    "columns of C (" GBd ")", GB_NROWS (M), GB_NCOLS (C)))) ;
             }
         }
         else if (col_assign)
@@ -198,8 +198,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             if (GB_NROWS (M) != GB_NROWS (C))
             { 
                 return (GB_ERROR (GrB_DIMENSION_MISMATCH, (GB_LOG,
-                    "mask vector m length is "GBd"; must match the number of "
-                    "rows of C ("GBd")", GB_NROWS (M), GB_NROWS (C)))) ;
+                    "Mask vector m length is " GBd "; must match the number of "
+                    "rows of C (" GBd ")", GB_NROWS (M), GB_NROWS (C)))) ;
             }
         }
         else
@@ -210,8 +210,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             if (GB_NROWS (M) != GB_NROWS (C) || GB_NCOLS (M) != GB_NCOLS (C))
             { 
                 return (GB_ERROR (GrB_DIMENSION_MISMATCH, (GB_LOG,
-                    "mask M is "GBd"-by-"GBd"; "
-                    "must match result C ("GBd"-by-"GBd")",
+                    "Mask M is " GBd "-by-" GBd "; "
+                    "must match result C (" GBd "-by-" GBd ")",
                     GB_NROWS (M), GB_NCOLS (M), GB_NROWS (C), GB_NCOLS (C)))) ;
             }
         }
@@ -226,8 +226,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
         { 
             return (GB_ERROR (GrB_DIMENSION_MISMATCH, (GB_LOG,
                 "Dimensions not compatible:\n"
-                "C(Rows,Cols) is "GBd"-by-"GBd"\n"
-                "input is "GBd"-by-"GBd"%s",
+                "C(Rows,Cols) is " GBd "-by-" GBd "\n"
+                "input is " GBd "-by-" GBd "%s",
                 nRows, nCols, anrows, ancols,
                 A_transpose ? " (transposed)" : ""))) ;
         }
@@ -255,7 +255,7 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             if (row_assign || col_assign)
             {
                 // all pending tuples must first be assembled; zombies OK
-                GB_WAIT_PENDING (C) ;
+                GB_MATRIX_WAIT_PENDING (C) ;
                 ASSERT_MATRIX_OK (C, "waited C for quick mask", GB0) ;
                 if ((row_assign && !C_is_csc) || (col_assign && C_is_csc))
                 { 
@@ -282,11 +282,7 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             }
         }
 
-        if (C->nzombies > 0)
-        { 
-            // make sure C is in the queue
-            GB_CRITICAL (GB_queue_insert (C)) ;
-        }
+        if (C->nzombies > 0) { if (!GB_queue_insert (C)) GB_PANIC ; } // TODO in 4.0: delete
         // finalize C if blocking mode is enabled, and return result
         ASSERT_MATRIX_OK (C, "Final C for assign, quick mask", GB0) ;
         return (GB_block (C, Context)) ;
@@ -332,10 +328,10 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
 
     // delete any lingering zombies and assemble any pending tuples
     // but only in A and M, not C
-    GB_WAIT (M) ;
+    GB_MATRIX_WAIT (M) ;
     if (!scalar_expansion)
     { 
-        GB_WAIT (A) ;
+        GB_MATRIX_WAIT (A) ;
     }
 
     //--------------------------------------------------------------------------
@@ -450,7 +446,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
         // AT = A', with no typecasting
         // transpose: no typecast, no op, not in place
         GBBURBLE ("(A transpose) ") ;
-        GB_OK (GB_transpose (&AT, NULL, C_is_csc, A, NULL, Context)) ;
+        GB_OK (GB_transpose (&AT, NULL, C_is_csc, A,
+            NULL, NULL, NULL, false, Context)) ;
         A = AT ;
     }
 
@@ -553,7 +550,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             // typecast to boolean, if a full matrix transpose is done.
             // transpose: typecast, no op, not in place
             GBBURBLE ("(M transpose) ") ;
-            GB_OK (GB_transpose (&MT, GrB_BOOL, C_is_csc, M, NULL, Context)) ;
+            GB_OK (GB_transpose (&MT, GrB_BOOL, C_is_csc, M,
+                NULL, NULL, NULL, false, Context)) ;
             M = MT ;
         }
     }
@@ -593,9 +591,9 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             // is needed because C is aliased with M or A.  Instead of
             // duplicating it, create an empty matrix Z2.  This also prevents
             // the C_replace_phase from being needed.
-            GB_NEW (&Z2, C->type, C->vlen, C->vdim, GB_Ap_calloc, C->is_csc,
-                GB_SAME_HYPER_AS (C->is_hyper), C->hyper_ratio, 1, Context) ;
-            GB_OK (info)  ;
+            GB_OK (GB_new (&Z2, C->type, C->vlen, C->vdim, GB_Ap_calloc,
+                C->is_csc, GB_SAME_HYPER_AS (C->is_hyper), C->hyper_ratio, 1,
+                Context)) ;
             GBBURBLE ("(C alias cleared; C_replace early) ") ;
             C_replace = false ;
             C_replace_phase = false ;
@@ -687,7 +685,7 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
 
         if (GB_PENDING (Z))
         { 
-            GB_OK (GB_wait (Z, Context)) ;
+            GB_OK (GB_Matrix_wait (Z, Context)) ;
         }
 
         ASSERT_MATRIX_OK (Z, "Z cleaned up for C-replace-phase", GB0) ;
@@ -704,7 +702,8 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
             // typecast to boolean, if a full matrix transpose is done.
             // transpose: typecast, no op, not in place
             GBBURBLE ("(M transpose) ") ;
-            GB_OK (GB_transpose (&MT, GrB_BOOL, C_is_csc, M, NULL, Context)) ;
+            GB_OK (GB_transpose (&MT, GrB_BOOL, C_is_csc, M,
+                NULL, NULL, NULL, false, Context)) ;
             M = MT ;
         }
 
@@ -796,7 +795,6 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
                 I, nI, Ikind, Icolon, J, nJ, Jkind, Jcolon, Context)) ;
         }
 
-        // Z is valid, but it has zombies and it not in the queue.
         ASSERT_MATRIX_OK (Z, "Z for C-replace-phase done", GB_FLIP (GB0)) ;
     }
 
@@ -810,28 +808,20 @@ GrB_Info GB_assign                  // C<M>(Rows,Cols) += A or A'
         if (GB_PENDING (Z2))
         { 
             // assemble all pending tuples, and delete all zombies too
-            GB_OK (GB_wait (Z2, Context)) ;
+            GB_OK (GB_Matrix_wait (Z2, Context)) ;
         }
         // transplants the content of Z into C and frees Z
         GB_OK (GB_transplant (C, C->type, &Z2, Context)) ;
     }
 
     // The hypersparsity of C is not modified.  This will be done eventually,
-    // when all pending operations are completed via GB_wait.
+    // when all pending operations are completed via GB_Matrix_wait.
 
     //--------------------------------------------------------------------------
     // free workspace, finalize C, and return result
     //--------------------------------------------------------------------------
 
-    if (C->nzombies > 0)
-    { 
-        // make sure C is in the queue.  GB_subassigner can place it in the
-        // queue, but it might not need to if the matrix has no zombies or
-        // pending tuples.  Zombies can be added by the C_replace_phase.
-        GB_CRITICAL (GB_queue_insert (C)) ;
-    }
-
-    // finalize C if blocking mode is enabled, and return result
+    if (C->nzombies > 0) { if (!GB_queue_insert (C)) GB_PANIC ; }// TODO in 4.0: delete
 
     ASSERT_MATRIX_OK (C, "Final C for assign", GB0) ;
     GB_FREE_ALL ;
