@@ -64,7 +64,7 @@ GrB_Info GB_compatible          // SUCCESS if all is OK, *_MISMATCH otherwise
     if (!GB_Type_compatible (ctype, ttype))
     { 
         return (GB_ERROR (GrB_DOMAIN_MISMATCH, (GB_LOG,
-            "result of computation of type [%s]\n"
+            "Result of computation of type [%s]\n"
             "cannot be typecast to final output of type [%s]",
             ttype->name, ctype->name))) ;
     }
