@@ -11,14 +11,13 @@
 
 void GB_ek_slice_free
 (
-    int64_t *GB_RESTRICT *pstart_slice_handle, // size ntasks+1
-    int64_t *GB_RESTRICT *kfirst_slice_handle, // size ntasks
-    int64_t *GB_RESTRICT *klast_slice_handle,  // size ntasks
-    int ntasks                              // # of tasks
+    int64_t *GB_RESTRICT *pstart_slice_handle,
+    int64_t *GB_RESTRICT *kfirst_slice_handle,
+    int64_t *GB_RESTRICT *klast_slice_handle
 )
 { 
-    GB_FREE_MEMORY ((*pstart_slice_handle), ntasks+1, sizeof (int64_t)) ;
-    GB_FREE_MEMORY ((*kfirst_slice_handle), ntasks, sizeof (int64_t)) ;
-    GB_FREE_MEMORY ((*klast_slice_handle), ntasks, sizeof (int64_t)) ;
+    GB_FREE (*pstart_slice_handle) ;
+    GB_FREE (*kfirst_slice_handle) ;
+    GB_FREE (*klast_slice_handle) ;
 }
 
