@@ -14,11 +14,14 @@
 // result is the same if A is in CSR or CSC format.
 
 #include "GB_reduce.h"
+#include "GB_binop.h"
 #include "GB_atomics.h"
 #ifndef GBCOMPACT
 #include "GB_red__include.h"
 #endif
 
+#define GB_FREE_ALL ;
+
 GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
 (
     void *c,                    // result scalar
@@ -34,6 +37,7 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     // check inputs
     //--------------------------------------------------------------------------
 
+    GrB_Info info ;
     GB_RETURN_IF_NULL_OR_FAULTY (reduce) ;
     GB_RETURN_IF_FAULTY (accum) ;
     GB_RETURN_IF_NULL (c) ;
@@ -45,17 +49,13 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
 
     // check domains and dimensions for c = accum (c,s)
     GrB_Type ztype = reduce->op->ztype ;
-    GrB_Info info = GB_compatible (ctype, NULL, NULL, accum, ztype, Context) ;
-    if (info != GrB_SUCCESS)
-    { 
-        return (info) ;
-    }
+    GB_OK (GB_compatible (ctype, NULL, NULL, accum, ztype, Context)) ;
 
     // s = reduce (s,A) must be compatible
     if (!GB_Type_compatible (A->type, ztype))
     { 
         return (GB_ERROR (GrB_DOMAIN_MISMATCH, (GB_LOG,
-            "incompatible type for reduction operator z=%s(x,y):\n"
+            "Incompatible type for reduction operator z=%s(x,y):\n"
             "input of type [%s]\n"
             "cannot be typecast to reduction operator of type [%s]",
             reduce->op->name, A->type->name, reduce->op->ztype->name))) ;
@@ -65,8 +65,7 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     // delete any lingering zombies and assemble any pending tuples
     //--------------------------------------------------------------------------
 
-    GB_WAIT (A) ;
-    ASSERT (!GB_PENDING (A)) ; ASSERT (!GB_ZOMBIES (A)) ;
+    GB_MATRIX_WAIT (A) ;
 
     //--------------------------------------------------------------------------
     // get A
@@ -77,21 +76,38 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     int64_t anz = GB_NNZ (A) ;
 
     //--------------------------------------------------------------------------
-    // determine the number of threads to use
+    // determine the number of OpenMP threads and/or GPUs to use
     //--------------------------------------------------------------------------
 
-    GB_GET_NTHREADS_MAX (nthreads_max, chunk, Context) ;
-    int nthreads = GB_nthreads (anz, chunk, nthreads_max) ;
-    int ntasks = (nthreads == 1) ? 1 : (64 * nthreads) ;
-    ntasks = GB_IMIN (ntasks, anz) ;
-    ntasks = GB_IMAX (ntasks, 1) ;
+    int nthreads = 0, ntasks = 0 ;
+    int ngpus_to_use = GB_ngpus_to_use ((double) anz) ;
+    int blocksize = 0 ;
+
+    if (ngpus_to_use > 0)
+    {
+        // use the GPU
+        blocksize = 512 ;                                   // blockDim.x
+        // TODO for GPU: grid.x is too large
+        ntasks = GB_ICEIL (anz, 8*blocksize) ;              // grid.x
+        // ntasks = (anz + 8*blocksize - 1) / (8*blocksize) ;
+        ngpus_to_use = 1 ;              // assume one GPU (TODO for GPU)
+        nthreads = ngpus_to_use ;       // use one CPU thread per GPU
+    }
+    else
+    {
+        // use the CPU
+        GB_GET_NTHREADS_MAX (nthreads_max, chunk, Context) ;
+        nthreads = GB_nthreads (anz, chunk, nthreads_max) ;
+        ntasks = (nthreads == 1) ? 1 : (64 * nthreads) ;
+        ntasks = GB_IMIN (ntasks, anz) ;
+        ntasks = GB_IMAX (ntasks, 1) ;
+    }
 
     //--------------------------------------------------------------------------
     // allocate workspace
     //--------------------------------------------------------------------------
 
-    GB_void *GB_RESTRICT W = NULL ;
-    GB_MALLOC_MEMORY (W, ntasks, zsize) ;
+    GB_void *GB_RESTRICT W = GB_MALLOC (ntasks * zsize, GB_void) ;
     if (W == NULL)
     { 
         // out of memory
@@ -107,7 +123,7 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     memcpy (s, reduce->identity, zsize) ;
 
     // get terminal value, if any
-    GB_void *GB_RESTRICT terminal = reduce->terminal ;
+    GB_void *GB_RESTRICT terminal = (GB_void *) reduce->terminal ;
 
     if (anz == 0)
     { 
@@ -123,37 +139,31 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     {
 
         //----------------------------------------------------------------------
-        // sum up the entries; no typecasting needed
+        // reduce to scalar via built-in operator
         //----------------------------------------------------------------------
 
-        // There are 44 common cases of this function for built-in types and
-        // operators.  Four associative operators: MIN, MAX, PLUS, and TIMES
-        // with 10 types (int*, uint*, float, and double), and four logical
-        // operators (OR, AND, XOR, EQ) with a boolean type of C.  All 44 are
-        // hard-coded below via a switch factory.  If the case is not handled
-        // by the switch factory, 'done' remains false.  The hard-coded workers
-        // do no typecasting at all.
-
         bool done = false ;
 
-        // define the worker for the switch factory
-
-        #define GB_red(opname,aname) GB_red_scalar_ ## opname ## aname
-
-        #define GB_RED_WORKER(opname,aname,atype)                       \
-        {                                                               \
-            info = GB_red (opname, aname) ((atype *) s, A, W,           \
-                ntasks, nthreads) ;                                     \
-            done = (info != GrB_NO_VALUE) ;                             \
-        }                                                               \
-        break ;
-
-        //----------------------------------------------------------------------
-        // launch the switch factory
-        //----------------------------------------------------------------------
-
         #ifndef GBCOMPACT
 
+            //------------------------------------------------------------------
+            // define the worker for the switch factory
+            //------------------------------------------------------------------
+
+            #define GB_red(opname,aname) GB_red_scalar_ ## opname ## aname
+
+            #define GB_RED_WORKER(opname,aname,atype)                       \
+            {                                                               \
+                info = GB_red (opname, aname) ((atype *) s, A, W,           \
+                    ntasks, nthreads) ;                                     \
+                done = (info != GrB_NO_VALUE) ;                             \
+            }                                                               \
+            break ;
+
+            //------------------------------------------------------------------
+            // launch the switch factory
+            //------------------------------------------------------------------
+
             // controlled by opcode and typecode
             GB_Opcode opcode = reduce->op->opcode ;
             GB_Type_code typecode = A->type->code ;
@@ -203,52 +213,25 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
                     if (memcmp (s, terminal, zsize) == 0) break ;   \
                 }
 
+            // skip the work for this task if early exit is reached
+            #define GB_IF_NOT_EARLY_EXIT                            \
+                bool my_exit ;                                      \
+                GB_ATOMIC_READ                                      \
+                my_exit = early_exit ;                              \
+                if (!my_exit)
 
-            #if GB_MICROSOFT
-
-                // skip the work for this task if early exit is reached
-                #define GB_IF_NOT_EARLY_EXIT                            \
-                    bool my_exit ;                                      \
-                    GB_PRAGMA (omp critical (GB_reduce_to_scalar))      \
-                    my_exit = early_exit ;                              \
-                    if (!my_exit)
-
-                // break if terminal value reached, inside parallel task
-                #define GB_PARALLEL_BREAK_IF_TERMINAL(s)                \
-                    if (terminal != NULL)                               \
-                    {                                                   \
-                        if (memcmp (s, terminal, zsize) == 0)           \
-                        {                                               \
-                            /* tell the other tasks to exit early */    \
-                            GB_PRAGMA (omp critical (GB_reduce_to_scalar))  \
-                            early_exit = true ;                         \
-                            break ;                                     \
-                        }                                               \
-                    }
-
-            #else
-
-                // skip the work for this task if early exit is reached
-                #define GB_IF_NOT_EARLY_EXIT                            \
-                    bool my_exit ;                                      \
-                    GB_ATOMIC_READ                                      \
-                    my_exit = early_exit ;                              \
-                    if (!my_exit)
-
-                // break if terminal value reached, inside parallel task
-                #define GB_PARALLEL_BREAK_IF_TERMINAL(s)                \
-                    if (terminal != NULL)                               \
-                    {                                                   \
-                        if (memcmp (s, terminal, zsize) == 0)           \
-                        {                                               \
-                            /* tell the other tasks to exit early */    \
-                            GB_ATOMIC_WRITE                             \
-                            early_exit = true ;                         \
-                            break ;                                     \
-                        }                                               \
-                    }
-
-            #endif
+            // break if terminal value reached, inside parallel task
+            #define GB_PARALLEL_BREAK_IF_TERMINAL(s)                \
+                if (terminal != NULL)                               \
+                {                                                   \
+                    if (memcmp (s, terminal, zsize) == 0)           \
+                    {                                               \
+                        /* tell the other tasks to exit early */    \
+                        GB_ATOMIC_WRITE                             \
+                        early_exit = true ;                         \
+                        break ;                                     \
+                    }                                               \
+                }
 
             // ztype t ;
             #define GB_SCALAR(t)                                    \
@@ -339,7 +322,7 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     // free workspace and return result
     //--------------------------------------------------------------------------
 
-    GB_FREE_MEMORY (W, ntasks, zsize) ;
+    GB_FREE (W) ;
     return (GrB_SUCCESS) ;
 }
 
