@@ -13,6 +13,7 @@
 // to a vector.
 
 #include "GB_reduce.h"
+#include "GB_binop.h"
 #include "GB_build.h"
 #include "GB_ek_slice.h"
 #include "GB_accum_mask.h"
@@ -20,11 +21,11 @@
 #include "GB_red__include.h"
 #endif
 
-#define GB_FREE_WORK                                                        \
-{                                                                           \
-    GB_FREE_MEMORY (Wfirst_space, ntasks, zsize) ;                          \
-    GB_FREE_MEMORY (Wlast_space,  ntasks, zsize) ;                          \
-    GB_ek_slice_free (&pstart_slice, &kfirst_slice, &klast_slice, ntasks) ; \
+#define GB_FREE_WORK                                                    \
+{                                                                       \
+    GB_FREE (Wfirst_space) ;                                            \
+    GB_FREE (Wlast_space) ;                                             \
+    GB_ek_slice_free (&pstart_slice, &kfirst_slice, &klast_slice) ;     \
 }
 
 #define GB_FREE_ALL             \
@@ -99,7 +100,7 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     if (!GB_Type_compatible (A->type, reduce->ztype))
     { 
         return (GB_ERROR (GrB_DOMAIN_MISMATCH, (GB_LOG,
-            "incompatible type for reduction operator z=%s(x,y):\n"
+            "Incompatible type for reduction operator z=%s(x,y):\n"
             "input matrix A of type [%s]\n"
             "cannot be typecast to reduction operator of type [%s]",
             reduce->name, A->type->name, reduce->ztype->name))) ;
@@ -112,8 +113,8 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
         if (n != GB_NCOLS (A))
         { 
             return (GB_ERROR (GrB_DIMENSION_MISMATCH, (GB_LOG,
-                "w=reduce(A'):  length of w is "GBd";\n"
-                "it must match the number of columns of A, which is "GBd".",
+                "w=reduce(A'):  length of w is " GBd ";\n"
+                "it must match the number of columns of A, which is " GBd ".",
                 n, GB_NCOLS (A)))) ;
         }
     }
@@ -122,8 +123,8 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
         if (n != GB_NROWS(A))
         { 
             return (GB_ERROR (GrB_DIMENSION_MISMATCH, (GB_LOG,
-                "w=reduce(A):  length of w is "GBd";\n"
-                "it must match the number of rows of A, which is "GBd".",
+                "w=reduce(A):  length of w is " GBd ";\n"
+                "it must match the number of rows of A, which is " GBd ".",
                 n, GB_NROWS (A)))) ;
         }
     }
@@ -135,11 +136,8 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     // delete any lingering zombies and assemble any pending tuples
     //--------------------------------------------------------------------------
 
-    // GB_WAIT (C) ;
-    GB_WAIT (M) ;
-    GB_WAIT (A) ;
-
-    ASSERT (!GB_PENDING (A)) ; ASSERT (!GB_ZOMBIES (A)) ;
+    GB_MATRIX_WAIT (M) ;
+    GB_MATRIX_WAIT (A) ;
 
     //--------------------------------------------------------------------------
     // handle the CSR/CSC format of A
@@ -183,7 +181,7 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     size_t asize = A->type->size ;
     GB_Type_code acode = A->type->code ;
     const int64_t *GB_RESTRICT Ai = A->i ;
-    const GB_void *GB_RESTRICT Ax = A->x ;
+    const GB_void *GB_RESTRICT Ax = (GB_void *) A->x ;
     int64_t anvec = A->nvec ;
     int64_t anz = GB_NNZ (A) ;
 
@@ -219,15 +217,14 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
         //----------------------------------------------------------------------
 
         // since T is a GrB_Vector, it is CSC and not hypersparse
-        GB_CREATE (&T, ttype, n, 1, GB_Ap_calloc, true,
-            GB_FORCE_NONHYPER, GB_HYPER_DEFAULT, 1, anvec, true, Context) ;
-        GB_OK (info) ;
+        GB_OK (GB_create (&T, ttype, n, 1, GB_Ap_calloc, true,
+            GB_FORCE_NONHYPER, GB_HYPER_DEFAULT, 1, anvec, true, Context)) ;
         ASSERT (GB_VECTOR_OK (T)) ;
 
         T->p [0] = 0 ;
         T->p [1] = anvec ;
         int64_t *GB_RESTRICT Ti = T->i ;
-        GB_void *GB_RESTRICT Tx = T->x ;
+        GB_void *GB_RESTRICT Tx = (GB_void *) T->x ;
         T->nvec_nonempty = (anvec > 0) ? 1 : 0 ;
         T->magic = GB_MAGIC ;
 
@@ -284,8 +281,8 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
         ntasks = GB_IMIN (ntasks, anz) ;
         ntasks = GB_IMAX (ntasks, 1) ;
 
-        GB_MALLOC_MEMORY (Wfirst_space, ntasks, zsize) ;
-        GB_MALLOC_MEMORY (Wlast_space,  ntasks, zsize) ;
+        Wfirst_space = GB_MALLOC (ntasks * zsize, GB_void) ;
+        Wlast_space  = GB_MALLOC (ntasks * zsize, GB_void) ;
 
         if (Wfirst_space == NULL || Wlast_space == NULL ||
            !GB_ek_slice (&pstart_slice, &kfirst_slice, &klast_slice, A, ntasks))
@@ -296,13 +293,17 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
         }
 
         //----------------------------------------------------------------------
-        // numeric phase: launch the switch factory
+        // reduce to vector with built-in operators
         //----------------------------------------------------------------------
 
         bool done = false ;
 
         #ifndef GBCOMPACT
 
+            //------------------------------------------------------------------
+            // define the worker for the switch factory
+            //------------------------------------------------------------------
+
             #define GB_red(opname,aname) GB_red_eachvec_ ## opname ## aname
             #define GB_RED_WORKER(opname,aname,atype)                       \
             {                                                               \
@@ -387,7 +388,7 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
             ASSERT (GB_VECTOR_OK (T)) ;
             ASSERT (!GB_PENDING (T)) ;
             ASSERT (GB_ZOMBIES (T)) ;
-            GB_OK (GB_wait (T, Context)) ;
+            GB_OK (GB_Matrix_wait (T, Context)) ;
         }
 
         ASSERT_MATRIX_OK (T, "T output = reduce_each_vector (A)", GB0) ;
@@ -425,9 +426,8 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
             // on n.
 
             // since T is a GrB_Vector, it is not hypersparse
-            GB_NEW (&T, ttype, n, 1, GB_Ap_null, true, GB_FORCE_NONHYPER,
-                GB_HYPER_DEFAULT, 1, Context) ;
-            GB_OK (info) ;
+            GB_OK (GB_new (&T, ttype, n, 1, GB_Ap_null, true, GB_FORCE_NONHYPER,
+                GB_HYPER_DEFAULT, 1, Context)) ;
 
             // GB_build treats Ai and Ax as read-only; they must not be modified
             GB_OK (GB_build
@@ -472,7 +472,7 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
             // Thread tid does entries pstart_slice [tid] to
             // pstart_slice [tid+1]-1.  No need to compute kfirst or klast.
 
-            GB_MALLOC_MEMORY (pstart_slice, ntasks+1, sizeof (int64_t)) ;
+            pstart_slice = GB_MALLOC (ntasks+1, int64_t) ;
             if (pstart_slice == NULL)
             { 
                 // out of memory
@@ -483,30 +483,35 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
             GB_eslice (pstart_slice, anz, ntasks) ;
 
             //------------------------------------------------------------------
-            // sum across each index: T(i) = reduce (A (i,:))
+            // T(i) = reduce (A (i,:)), built-in operators
             //------------------------------------------------------------------
 
-            // Early exit cannot be exploited; ignore the terminal value.
-
-            #undef  GB_red
-            #define GB_red(opname,aname) GB_red_eachindex_ ## opname ## aname
-            #undef  GB_RED_WORKER
-            #define GB_RED_WORKER(opname,aname,atype)                       \
-            {                                                               \
-                info = GB_red (opname, aname) (&T, ttype, A, pstart_slice,  \
-                    ntasks, nthreads, Context) ;                            \
-                done = (info != GrB_NO_VALUE) ;                             \
-            }                                                               \
-            break ;
-
             bool done = false ;
 
-            //------------------------------------------------------------------
-            // launch the switch factory
-            //------------------------------------------------------------------
-
             #ifndef GBCOMPACT
 
+                //--------------------------------------------------------------
+                // define the worker for the switch factory
+                //--------------------------------------------------------------
+
+                // Early exit cannot be exploited; ignore the terminal value.
+
+                #undef  GB_red
+                #define GB_red(opname,aname) \
+                    GB_red_eachindex_ ## opname ## aname
+                #undef  GB_RED_WORKER
+                #define GB_RED_WORKER(opname,aname,atype)                      \
+                {                                                              \
+                    info = GB_red (opname, aname) (&T, ttype, A, pstart_slice, \
+                        ntasks, nthreads, Context) ;                           \
+                    done = (info != GrB_NO_VALUE) ;                            \
+                }                                                              \
+                break ;
+
+                //--------------------------------------------------------------
+                // launch the switch factory
+                //--------------------------------------------------------------
+
                 if (nocasting)
                 { 
                     // controlled by opcode and typecode.  No typecasting
@@ -525,7 +530,7 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
             #endif
 
             //------------------------------------------------------------------
-            // generic worker
+            // T(i) = reduce (A (i,:)), generic worker
             //------------------------------------------------------------------
 
             if (!done)
