@@ -21,6 +21,7 @@
 
 #include "GB.h"
 
+GB_PUBLIC   // accessed by the MATLAB tests in GraphBLAS/Test only
 GrB_Info GB_to_nonhyper     // convert a matrix to non-hypersparse
 (
     GrB_Matrix A,           // matrix to convert to non-hypersparse
@@ -59,7 +60,7 @@ GrB_Info GB_to_nonhyper     // convert a matrix to non-hypersparse
         //----------------------------------------------------------------------
 
         int64_t *GB_RESTRICT Ap_new ;
-        GB_MALLOC_MEMORY (Ap_new, n+1, sizeof (int64_t)) ;
+        Ap_new = GB_MALLOC (n+1, int64_t) ;
         if (Ap_new == NULL)
         { 
             // out of memory
