@@ -13,12 +13,17 @@
 #ifndef GB_UNUSED_H
 #define GB_UNUSED_H
 
-#if defined ( __INTEL_COMPILER )
+#if ( _MSC_VER && !__INTEL_COMPILER )
+// disable MS Visual Studio warnings
+GB_PRAGMA (warning (disable : 4101 ))
+#elif defined ( __INTEL_COMPILER )
 // disable icc -w3 warnings
 #pragma warning (disable: 177 593)
 #elif defined ( __GNUC__ )
 // disable gcc -Wall -Wextra -Wpedantic warnings
+#if (__GNUC__ > 4)
 #pragma GCC diagnostic ignored "-Wunused-but-set-variable"
+#endif
 #pragma GCC diagnostic ignored "-Wunused-variable"
 #endif
 
