@@ -24,8 +24,7 @@ GrB_Info GrB_Descriptor_free            // free a descriptor
         if (desc != NULL && desc->magic == GB_MAGIC && !(desc->predefined))
         { 
             desc->magic = GB_FREED ;     // to help detect dangling pointers
-            GB_FREE_MEMORY (*descriptor, 1,
-                sizeof (struct GB_Descriptor_opaque)) ;
+            GB_FREE (*descriptor) ;
         }
         (*descriptor) = NULL ;
     }
