@@ -30,7 +30,7 @@ GrB_Info GrB_Descriptor_new     // create a new descriptor
     //--------------------------------------------------------------------------
 
     // allocate the descriptor
-    GB_CALLOC_MEMORY (*descriptor, 1, sizeof (struct GB_Descriptor_opaque)) ;
+    (*descriptor) = GB_CALLOC (1, struct GB_Descriptor_opaque) ;
     if (*descriptor == NULL)
     { 
         // out of memory
@@ -47,6 +47,7 @@ GrB_Info GrB_Descriptor_new     // create a new descriptor
     desc->axb  = GxB_DEFAULT ;     // descriptor for selecting the C=A*B method
     desc->nthreads_max = GxB_DEFAULT ;  // max # of threads to use
     desc->chunk = GxB_DEFAULT ;         // chunk for auto-tuning of # threads
+    desc->use_mkl = false ;        // control usage of Intel MKL
     desc->predefined = false ;     // user-defined
     return (GrB_SUCCESS) ;
 }
