@@ -18,7 +18,7 @@ GrB_Info GrB_Monoid_free            // free a user-created monoid
     if (monoid != NULL)
     {
         GrB_Monoid mon = *monoid ;
-        if (mon != NULL && mon->object_kind == GB_USER_RUNTIME)
+        if (mon != NULL && !mon->builtin)
         {
             if (mon->magic == GB_MAGIC)
             { 
@@ -28,9 +28,9 @@ GrB_Info GrB_Monoid_free            // free a user-created monoid
                 // mon->op->ztype->size might not be safe if op or ztype are
                 // user-defined and have already been freed; use op_ztype_size.
                 size_t zsize = mon->op_ztype_size ;
-                GB_FREE_MEMORY (mon->identity, 1, zsize) ;
-                GB_FREE_MEMORY (mon->terminal, 1, zsize) ;
-                GB_FREE_MEMORY (*monoid, 1, sizeof (struct GB_Monoid_opaque)) ;
+                GB_FREE (mon->identity) ;
+                GB_FREE (mon->terminal) ;
+                GB_FREE (*monoid) ;
             }
             (*monoid) = NULL ;
         }
