@@ -13,8 +13,8 @@
 
 #include "GB_assign.h"
 
-#define GB_ASSIGN(type,T,ampersand)                                            \
-GrB_Info GrB_Vector_assign_ ## T    /* w<M>(Rows) = accum (w(Rows),x)       */ \
+#define GB_ASSIGN(prefix,type,T,ampersand)                                     \
+GrB_Info prefix ## Vector_assign_ ## T    /* w<M>(Rows) = accum (w(Rows),x) */ \
 (                                                                              \
     GrB_Vector w,                   /* input/output vector for results      */ \
     const GrB_Vector M,             /* optional mask for w                  */ \
@@ -25,7 +25,7 @@ GrB_Info GrB_Vector_assign_ ## T    /* w<M>(Rows) = accum (w(Rows),x)       */ \
     const GrB_Descriptor desc       /* descriptor for w and mask            */ \
 )                                                                              \
 {                                                                              \
-    GB_WHERE ("GrB_Vector_assign_" GB_STR(T)                                   \
+    GB_WHERE (GB_STR(prefix) "Vector_assign_" GB_STR(T)                        \
         " (w, M, accum, x, Rows, nRows, desc)") ;                              \
     GB_BURBLE_START ("GrB_assign") ;                                           \
     GB_RETURN_IF_NULL_OR_FAULTY (w) ;                                          \
@@ -39,16 +39,18 @@ GrB_Info GrB_Vector_assign_ ## T    /* w<M>(Rows) = accum (w(Rows),x)       */ \
     return (info) ;                                                            \
 }
 
-GB_ASSIGN (bool     , BOOL   , &)
-GB_ASSIGN (int8_t   , INT8   , &)
-GB_ASSIGN (uint8_t  , UINT8  , &)
-GB_ASSIGN (int16_t  , INT16  , &)
-GB_ASSIGN (uint16_t , UINT16 , &)
-GB_ASSIGN (int32_t  , INT32  , &)
-GB_ASSIGN (uint32_t , UINT32 , &)
-GB_ASSIGN (int64_t  , INT64  , &)
-GB_ASSIGN (uint64_t , UINT64 , &)
-GB_ASSIGN (float    , FP32   , &)
-GB_ASSIGN (double   , FP64   , &)
-GB_ASSIGN (void *   , UDT    ,  )
+GB_ASSIGN (GrB_, bool      , BOOL   , &)
+GB_ASSIGN (GrB_, int8_t    , INT8   , &)
+GB_ASSIGN (GrB_, uint8_t   , UINT8  , &)
+GB_ASSIGN (GrB_, int16_t   , INT16  , &)
+GB_ASSIGN (GrB_, uint16_t  , UINT16 , &)
+GB_ASSIGN (GrB_, int32_t   , INT32  , &)
+GB_ASSIGN (GrB_, uint32_t  , UINT32 , &)
+GB_ASSIGN (GrB_, int64_t   , INT64  , &)
+GB_ASSIGN (GrB_, uint64_t  , UINT64 , &)
+GB_ASSIGN (GrB_, float     , FP32   , &)
+GB_ASSIGN (GrB_, double    , FP64   , &)
+GB_ASSIGN (GxB_, GxB_FC32_t, FC32   , &)
+GB_ASSIGN (GxB_, GxB_FC64_t, FC64   , &)
+GB_ASSIGN (GrB_, void *    , UDT    ,  )
 
