@@ -19,8 +19,8 @@
 
 #include "GB.h"
 
-#define GB_EXTRACT(type,T)                                                    \
-GrB_Info GrB_Vector_extractTuples_ ## T     /* [I,~,X] = find (A) */          \
+#define GB_EXTRACT(prefix,type,T)                                             \
+GrB_Info prefix ## Vector_extractTuples_ ## T     /* [I,~,X] = find (A) */    \
 (                                                                             \
     GrB_Index *I,           /* array for returning row indices of tuples */   \
     type *X,                /* array for returning values of tuples      */   \
@@ -28,7 +28,8 @@ GrB_Info GrB_Vector_extractTuples_ ## T     /* [I,~,X] = find (A) */          \
     const GrB_Vector v      /* vector to extract tuples from             */   \
 )                                                                             \
 {                                                                             \
-    GB_WHERE ("GrB_Vector_extractTuples_" GB_STR(T) " (I, X, nvals, v)") ;    \
+    GB_WHERE (GB_STR(prefix) "Vector_extractTuples_" GB_STR(T)                \
+        " (I, X, nvals, v)") ;                                                \
     GB_BURBLE_START ("GrB_Vector_extractTuples") ;                            \
     GB_RETURN_IF_NULL_OR_FAULTY (v) ;                                         \
     GB_RETURN_IF_NULL (p_nvals) ;                                             \
@@ -39,16 +40,18 @@ GrB_Info GrB_Vector_extractTuples_ ## T     /* [I,~,X] = find (A) */          \
     return (info) ;                                                           \
 }
 
-GB_EXTRACT (bool     , BOOL   )
-GB_EXTRACT (int8_t   , INT8   )
-GB_EXTRACT (uint8_t  , UINT8  )
-GB_EXTRACT (int16_t  , INT16  )
-GB_EXTRACT (uint16_t , UINT16 )
-GB_EXTRACT (int32_t  , INT32  )
-GB_EXTRACT (uint32_t , UINT32 )
-GB_EXTRACT (int64_t  , INT64  )
-GB_EXTRACT (uint64_t , UINT64 )
-GB_EXTRACT (float    , FP32   )
-GB_EXTRACT (double   , FP64   )
-GB_EXTRACT (void     , UDT    )
+GB_EXTRACT (GrB_, bool      , BOOL   )
+GB_EXTRACT (GrB_, int8_t    , INT8   )
+GB_EXTRACT (GrB_, uint8_t   , UINT8  )
+GB_EXTRACT (GrB_, int16_t   , INT16  )
+GB_EXTRACT (GrB_, uint16_t  , UINT16 )
+GB_EXTRACT (GrB_, int32_t   , INT32  )
+GB_EXTRACT (GrB_, uint32_t  , UINT32 )
+GB_EXTRACT (GrB_, int64_t   , INT64  )
+GB_EXTRACT (GrB_, uint64_t  , UINT64 )
+GB_EXTRACT (GrB_, float     , FP32   )
+GB_EXTRACT (GrB_, double    , FP64   )
+GB_EXTRACT (GxB_, GxB_FC32_t, FC32   )
+GB_EXTRACT (GxB_, GxB_FC64_t, FC64   )
+GB_EXTRACT (GrB_, void      , UDT    )
 
